@@ -12,7 +12,7 @@
  */
 
 /**
- * @file common/commands.c
+ * @file
  * Handles server->client commands; See player.c for client->server commands.
  *
  * Not necessarily all commands are handled - some might be in other files
@@ -54,13 +54,13 @@
 
 int mapupdatesent = 0;
 
-#include <client.h>
-#include <external.h>
+#include "client.h"
 
 #include <assert.h>
 #include <ctype.h>
 #include <errno.h>
 
+#include "external.h"
 #include "mapdata.h"
 
 /* In general, the data from the server should not do bad
@@ -81,18 +81,18 @@ int mapupdatesent = 0;
 
 char *news=NULL, *motd=NULL, *rules=NULL;
 
-int spellmon_level = 0;                 /**< Keeps track of what spellmon
-                                         *   command is supported by the
-                                         *   server. */
+/** Keeps track of what spellmon command is supported by the server. */
+static int spellmon_level = 0;
+
 int num_races = 0;    /* Number of different races server has */
 int used_races = 0;   /* How many races we have filled in */
 
 int num_classes = 0;  /* Same as race data above, but for classes */
 int used_classes = 0;
 
-int stat_points = 0;    /* Number of stat points for new characters */
-int stat_min = 0;       /* Minimum stat for new characters */
-int stat_maximum = 0;   /* Maximum stat for new characters */
+int stat_points;    /* Number of stat points for new characters */
+int stat_min;       /* Minimum stat for new characters */
+int stat_maximum;   /* Maximum stat for new characters */
 int starting_map_number = 0;   /* Number of starting maps */
 
 Race_Class_Info *races=NULL, *classes=NULL;
@@ -104,7 +104,7 @@ Starting_Map_Info *starting_map_info = NULL;
 
 #define NUM_STATS 7
 /** Short name of stats. */
-const char *const short_stat_name[NUM_STATS] = {
+static const char *const short_stat_name[NUM_STATS] = {
     "Str",    "Dex",    "Con",
     "Wis",    "Cha",    "Int",
     "Pow"
@@ -169,8 +169,7 @@ void free_all_starting_map_info()
  * @param len
  * length of data.
  */
-static void get_starting_map_info(char *data, int len)
-{
+static void get_starting_map_info(unsigned char *data, int len) {
     int pos, type, length, map_entry=-1;
     char *cp;
 
@@ -192,8 +191,8 @@ static void get_starting_map_info(char *data, int len)
             return;
         }
 
-        cp = malloc(length+1);
-        strncpy(cp, data+pos, length);
+        cp = g_malloc(length+1);
+        strncpy(cp, (char *)data + pos, length);
         cp[length] = 0;
 
         pos += length;
@@ -201,12 +200,12 @@ static void get_starting_map_info(char *data, int len)
         /* If it is the arch name, it is a new entry, so we allocate
          * space and clear it.  This isn't most efficient, but at
          * the same time, I don't see there being many maps.
-         * Note: If realloc is given a null pointer (which starting_map_info
-         * will be after free or first load), realloc just acts as malloc.
+         * Note: If g_realloc is given a null pointer (which starting_map_info
+         * will be after free or first load), g_realloc just acts as g_malloc.
          */
         if (type == INFO_MAP_ARCH_NAME) {
             map_entry++;
-            starting_map_info = realloc(starting_map_info,
+            starting_map_info = g_realloc(starting_map_info,
                                         (map_entry + 1) * sizeof(Starting_Map_Info));
 
             if (starting_map_info == NULL) {
@@ -245,8 +244,7 @@ static void get_starting_map_info(char *data, int len)
  * @param len
  * length of data.
  */
-static void get_new_char_info(char *data, int len)
-{
+static void get_new_char_info(unsigned char *data, int len) {
     int olen=0, llen;
 
     /* We reset these values - if the user is switching between
@@ -293,7 +291,7 @@ static void get_new_char_info(char *data, int len)
             return;
         }
 
-        cp = data + olen;
+        cp = (char *)data + olen;
         /* Go until we find another space */
         while (olen <= len) {
             if (isspace(data[olen])) {
@@ -312,19 +310,19 @@ static void get_new_char_info(char *data, int len)
          * of the line, with data+olen is the start of the next string
          * (variable value).
          */
-        if (!strcasecmp(cp,"points")) {
-            stat_points = atoi(data+olen);
+        if (!g_ascii_strcasecmp(cp,"points")) {
+            stat_points = atoi((char *)data + olen);
             olen = llen + 1;
             continue;
-        } else if (!strcasecmp(cp,"statrange")) {
-            if (sscanf(data + olen, "%d %d", &stat_min, &stat_maximum)!=2) {
+        } else if (!g_ascii_strcasecmp(cp,"statrange")) {
+            if (sscanf((char *)data + olen, "%d %d", &stat_min, &stat_maximum) != 2) {
                 LOG(LOG_WARNING, "common::get_new_char_info",
                     "Unable to process statrange line (%s)", data + olen);
             }
             /* Either way, we go onto the next line */
             olen = llen + 1;
             continue;
-        } else if (!strcasecmp(cp,"statname")) {
+        } else if (!g_ascii_strcasecmp(cp,"statname")) {
             /* The checking we do here is somewhat basic:
              * 1) That we understand all the stat names that the server sends us
              * 2) That we get the correct number of stats.
@@ -337,7 +335,8 @@ static void get_new_char_info(char *data, int len)
 
             while (olen < llen) {
                 for (i=0; i < NUM_STATS; i++) {
-                    if (!strncasecmp(data + olen, short_stat_name[i], strlen(short_stat_name[i]))) {
+                    if (!g_ascii_strncasecmp((char *)data + olen,
+                            short_stat_name[i], strlen(short_stat_name[i]))) {
                         matches++;
                         olen += strlen(short_stat_name[i]) + 1;
                         break;
@@ -355,15 +354,15 @@ static void get_new_char_info(char *data, int len)
             }
             olen = llen + 1;
             continue;
-        } else if (!strcasecmp(cp,"race") || !strcasecmp(cp,"class")) {
-            if (strcasecmp(data+olen, "requestinfo")) {
+        } else if (!g_ascii_strcasecmp(cp,"race") || !g_ascii_strcasecmp(cp,"class")) {
+            if (g_ascii_strcasecmp((char *)data + olen, "requestinfo")) {
                 LOG(LOG_WARNING, "common::get_new_char_info",
                     "Got unexpected value for %s: %s", cp, data+olen);
             }
             olen = llen + 1;
             continue;
-        } else if (!strcasecmp(cp,"startingmap")) {
-            if (strcasecmp(data+olen, "requestinfo")) {
+        } else if (!g_ascii_strcasecmp(cp,"startingmap")) {
+            if (g_ascii_strcasecmp((char *)data + olen, "requestinfo")) {
                 LOG(LOG_WARNING, "common::get_new_char_info",
                     "Got unexpected value for %s: %s", cp, data+olen);
             } else {
@@ -405,7 +404,7 @@ static void get_new_char_info(char *data, int len)
  */
 static int rc_compar(const Race_Class_Info *a, const Race_Class_Info *b)
 {
-    return strcasecmp(a->public_name, b->public_name);
+    return g_ascii_strcasecmp(a->public_name, b->public_name);
 }
 
 /**
@@ -467,11 +466,8 @@ void free_all_race_class_info(Race_Class_Info *data, int num_entries)
  * @param rci
  * Where to store the data.
  */
-static void process_race_class_info(char *data, int len, Race_Class_Info *rci)
-{
-    char *cp, *nl;
-
-    cp = data;
+static void process_race_class_info(unsigned char *data, int len, Race_Class_Info *rci) {
+    char *cp = (char *)data, *nl;
 
     /* First thing is to process the remaining bit of the requestinfo line,
      * which is the archetype name for this race/class
@@ -479,7 +475,7 @@ static void process_race_class_info(char *data, int len, Race_Class_Info *rci)
     nl = strchr(cp, '\n');
     if (nl) {
         *nl=0;
-        rci->arch_name = strdup(cp);
+        rci->arch_name = g_strdup(cp);
         cp = nl+1;
     } else {
         LOG(LOG_WARNING, "common::process_race_class_info", "Did not find archetype name");
@@ -512,10 +508,11 @@ static void process_race_class_info(char *data, int len, Race_Class_Info *rci)
              */
             int namelen;
 
-            namelen = GetChar_String(nl);
-            ASSERT_LEN("common::process_race_class_info", nl + namelen, data + len);
+            namelen = GetChar_String((unsigned char *)nl);
+            ASSERT_LEN("common::process_race_class_info",
+                    (unsigned char *)nl + namelen, data + len);
             nl++;
-            rci->public_name = malloc(namelen+1);
+            rci->public_name = g_malloc(namelen+1);
             strncpy(rci->public_name, nl, namelen);
             rci->public_name[namelen] = 0;
             cp = nl + namelen;
@@ -524,7 +521,7 @@ static void process_race_class_info(char *data, int len, Race_Class_Info *rci)
             /* This loop goes through the stat values - *cp points to the stat
              * value - if 0, no more stats, hence the check here.
              */
-            while (cp < data + len && *cp != 0) {
+            while (cp < (char *)data + len && *cp != 0) {
                 int i;
 
                 for (i=0; i < NUM_NEW_CHAR_STATS; i++)
@@ -538,7 +535,8 @@ static void process_race_class_info(char *data, int len, Race_Class_Info *rci)
                         "Unknown stat value: %d", cp);
                     return;
                 }
-                rci->stat_adj[stat_mapping[i].rc_offset] = GetShort_String(cp+1);
+                rci->stat_adj[stat_mapping[i].rc_offset] =
+                        GetShort_String((unsigned char *)cp + 1);
                 cp += 3;
             }
             cp++;   /* Skip over 0 terminator */
@@ -548,10 +546,11 @@ static void process_race_class_info(char *data, int len, Race_Class_Info *rci)
              */
             int msglen;
 
-            msglen = GetShort_String(nl);
-            ASSERT_LEN("common::process_race_class_info", nl + msglen, data + len);
+            msglen = GetShort_String((unsigned char *)nl);
+            ASSERT_LEN("common::process_race_class_info",
+                    (unsigned char *)nl + msglen, data + len);
             nl+=2;
-            rci->description = malloc(msglen+1);
+            rci->description = g_malloc(msglen+1);
             strncpy(rci->description, nl, msglen);
             rci->description[msglen] = 0;
             cp = nl + msglen;
@@ -559,26 +558,28 @@ static void process_race_class_info(char *data, int len, Race_Class_Info *rci)
             int oc = rci->num_rc_choice, clen;
 
             rci->num_rc_choice++;
-            /* rc_choice may be null, but realloc still works there */
-            rci->rc_choice = realloc(rci->rc_choice, sizeof(struct RC_Choice) * rci->num_rc_choice);
+            /* rc_choice may be null, but g_realloc still works there */
+            rci->rc_choice = g_realloc(rci->rc_choice, sizeof(struct RC_Choice) * rci->num_rc_choice);
             memset(&rci->rc_choice[oc], 0, sizeof(struct RC_Choice));
 
             cp = nl;
 
             /* First is the coice string we return */
-            clen = GetChar_String(cp);
+            clen = GetChar_String((unsigned char *)cp);
             cp++;
-            ASSERT_LEN("common::process_race_class_info", cp + clen, data + len);
-            rci->rc_choice[oc].choice_name = malloc(clen+1);
+            ASSERT_LEN("common::process_race_class_info",
+                    (unsigned char *)cp + clen, data + len);
+            rci->rc_choice[oc].choice_name = g_malloc(clen+1);
             strncpy(rci->rc_choice[oc].choice_name, cp, clen);
             rci->rc_choice[oc].choice_name[clen] = 0;
             cp += clen;
 
             /* Next is the description */
-            clen = GetChar_String(cp);
+            clen = GetChar_String((unsigned char *)cp);
             cp++;
-            ASSERT_LEN("common::process_race_class_info", cp + clen, data + len);
-            rci->rc_choice[oc].choice_desc = malloc(clen+1);
+            ASSERT_LEN("common::process_race_class_info",
+                    (unsigned char *)cp + clen, data + len);
+            rci->rc_choice[oc].choice_desc = g_malloc(clen+1);
             strncpy(rci->rc_choice[oc].choice_desc, cp, clen);
             rci->rc_choice[oc].choice_desc[clen] = 0;
             cp += clen;
@@ -587,28 +588,30 @@ static void process_race_class_info(char *data, int len, Race_Class_Info *rci)
             while (1) {
                 int vn;
 
-                clen = GetChar_String(cp);
+                clen = GetChar_String((unsigned char *)cp);
                 cp++;
                 if (!clen) {
                     break;    /* 0 length is end of data */
                 }
                 vn = rci->rc_choice[oc].num_values;
                 rci->rc_choice[oc].num_values++;
-                rci->rc_choice[oc].value_arch = realloc(rci->rc_choice[oc].value_arch,
+                rci->rc_choice[oc].value_arch = g_realloc(rci->rc_choice[oc].value_arch,
                                                         sizeof(char*) * rci->rc_choice[oc].num_values);
-                rci->rc_choice[oc].value_desc = realloc(rci->rc_choice[oc].value_desc,
+                rci->rc_choice[oc].value_desc = g_realloc(rci->rc_choice[oc].value_desc,
                                                         sizeof(char*) * rci->rc_choice[oc].num_values);
 
-                ASSERT_LEN("common::process_race_class_info", cp + clen, data + len);
-                rci->rc_choice[oc].value_arch[vn] = malloc(clen+1);
+                ASSERT_LEN("common::process_race_class_info",
+                        (unsigned char *)cp + clen, data + len);
+                rci->rc_choice[oc].value_arch[vn] = g_malloc(clen+1);
                 strncpy(rci->rc_choice[oc].value_arch[vn], cp, clen);
                 rci->rc_choice[oc].value_arch[vn][clen] = 0;
                 cp += clen;
 
-                clen = GetChar_String(cp);
+                clen = GetChar_String((unsigned char *)cp);
                 cp++;
-                ASSERT_LEN("common::process_race_class_info", cp + clen, data + len);
-                rci->rc_choice[oc].value_desc[vn] = malloc(clen+1);
+                ASSERT_LEN("common::process_race_class_info",
+                        (unsigned char *)cp + clen, data + len);
+                rci->rc_choice[oc].value_desc[vn] = g_malloc(clen+1);
                 strncpy(rci->rc_choice[oc].value_desc[vn], cp, clen);
                 rci->rc_choice[oc].value_desc[vn][clen] = 0;
                 cp += clen;
@@ -621,14 +624,14 @@ static void process_race_class_info(char *data, int len, Race_Class_Info *rci)
             LOG(LOG_WARNING, "common::process_race_class_info", "Got unknown keyword: %s", cp);
             break;
         }
-    } while (cp < data+len);
+    } while ((unsigned char *)cp < data + len);
 
     /* The display code expects all of these to have a description -
      * rather than add checks there for NULL values, simpler to
      * just set things to an empty value.
      */
     if (!rci->description) {
-        rci->description = strdup("");
+        rci->description = g_strdup("");
     }
 
 }
@@ -642,9 +645,7 @@ static void process_race_class_info(char *data, int len, Race_Class_Info *rci)
  * @param len
  * length of data.
  */
-static void get_race_info(char *data, int len)
-{
-
+static void get_race_info(unsigned char *data, int len) {
     /* This should not happen - the client is only requesting race info for
      * races it has received - and it knows how many of those it has.
      */
@@ -675,9 +676,7 @@ static void get_race_info(char *data, int len)
  * @param len
  * length of data.
  */
-static void get_class_info(char *data, int len)
-{
-
+static void get_class_info(unsigned char *data, int len) {
     /* This should not happen - the client is only requesting race info for
      * classes it has received - and it knows how many of those it has.
      */
@@ -714,7 +713,7 @@ static void get_exp_info(const unsigned char *data, int len)
 
     exp_table_max = GetShort_String(data);
     pos = 2;
-    exp_table = calloc(exp_table_max, sizeof(uint64));
+    exp_table = calloc(exp_table_max, sizeof(guint64));
     for (level = 1; level <= exp_table_max && pos < len; level++) {
         exp_table[level] = GetInt64_String(data+pos);
         pos += 8;
@@ -760,7 +759,7 @@ static void get_skill_info(char *data, int len)
         }
 
         free(skill_names[val]);
-        skill_names[val] = strdup_local(sn);
+        skill_names[val] = g_strdup(sn);
         cp = nl;
     } while (cp < data+len);
 }
@@ -772,9 +771,8 @@ static void get_skill_info(char *data, int len)
  * @param buf
  * @param len
  */
-void ReplyInfoCmd(uint8 *buf, int len)
-{
-    uint8 *cp;
+void ReplyInfoCmd(unsigned char *buf, int len) {
+    unsigned char *cp;
     int i;
 
     /* Covers a bug in the server in that it could send a replyinfo with no
@@ -815,22 +813,22 @@ void ReplyInfoCmd(uint8 *buf, int len)
         if (motd) {
             free((char*)motd);
         }
-        motd = strdup(cp);
+        motd = g_strdup((char *)cp);
         update_login_info(INFO_MOTD);
     } else if (!strcmp((char*)buf, "news")) {
         if (news) {
             free((char*)news);
         }
-        news = strdup(cp);
+        news = g_strdup((char *)cp);
         update_login_info(INFO_NEWS);
     } else if (!strcmp((char*)buf, "rules")) {
         if (rules) {
             free((char*)rules);
         }
-        rules = strdup(cp);
+        rules = g_strdup((char *)cp);
         update_login_info(INFO_RULES);
     } else if (!strcmp((char*)buf, "race_list")) {
-        char *cp1;
+        unsigned char *cp1;
         for (cp1=cp; *cp !=0; cp++) {
             if (*cp == '|') {
                 *cp++ = '\0';
@@ -856,7 +854,7 @@ void ReplyInfoCmd(uint8 *buf, int len)
         races = calloc(num_races, sizeof(Race_Class_Info));
 
     }  else if (!strcmp((char*)buf, "class_list")) {
-        char *cp1;
+        unsigned char *cp1;
         for (cp1=cp; *cp !=0; cp++) {
             if (*cp == '|') {
                 *cp++ = '\0';
@@ -954,7 +952,7 @@ void SetupCmd(char *buf, int len)
             int x, y = 0;
             char *cp, tmpbuf[MAX_BUF];
 
-            if (!strcasecmp(param, "false")) {
+            if (!g_ascii_strcasecmp(param, "false")) {
                 draw_ext_info(NDI_RED, MSG_TYPE_CLIENT, MSG_TYPE_CLIENT_SERVER,
                               "Server only supports standard sized maps (11x11)");
                 /* Do this because we may have been playing on a big server
@@ -1050,7 +1048,7 @@ void SetupCmd(char *buf, int len)
                               "Server does not support map2cmd!");
                 draw_ext_info(NDI_RED, MSG_TYPE_CLIENT, MSG_TYPE_CLIENT_SERVER,
                               "This server is too old to support this client!");
-                close_server_connection();
+                client_disconnect();
             }
         } else if (!strcmp(cmd, "want_pickup")) {
             /* Nothing special to do as this is info pushed from server and
@@ -1067,8 +1065,9 @@ void SetupCmd(char *buf, int len)
                 start_login(method);
             }
         } else {
-            LOG(LOG_INFO, "common::SetupCmd", "Got setup for a command we don't understand: %s %s",
-                cmd, param);
+            LOG(LOG_INFO, "common::SetupCmd",
+                    "Got setup for a command we don't understand: %s %s",
+                    cmd, param);
         }
     }
 }
@@ -1103,7 +1102,7 @@ void AddMeSuccess(char *data, int len)
     (void)len; /* __UNUSED__ */
 
     hide_all_login_windows();
-    LOG(LOG_INFO, "common::AddMeSuccess", "addme_success received.");
+    LOG(LOG_DEBUG, "common::AddMeSuccess", "addme_success received.");
     return;
 }
 
@@ -1150,7 +1149,7 @@ void AnimCmd(unsigned char *data, int len)
             animations[anum].num_animations);
         return;
     }
-    animations[anum].faces = malloc(sizeof(uint16)*animations[anum].num_animations);
+    animations[anum].faces = g_malloc(sizeof(guint16)*animations[anum].num_animations);
     for (i = 4, j = 0; i < len; i += 2, j++) {
         animations[anum].faces[j] = GetShort_String(data+i);
     }
@@ -1179,8 +1178,8 @@ void AnimCmd(unsigned char *data, int len)
  */
 void SmoothCmd(unsigned char *data, int len)
 {
-    uint16 faceid;
-    uint16 smoothing;
+    guint16 faceid;
+    guint16 smoothing;
 
     /* len is unused.  We should check that we don't have an invalid short
      * command.  Hence, the compiler warning is valid.
@@ -1232,7 +1231,7 @@ void setTextManager(int type, ExtTextManager callback)
         }
         current = current->next;
     }
-    current = malloc(sizeof(TextManager));
+    current = g_malloc(sizeof(TextManager));
     current->type = type;
     current->callback = callback;
     current->next = firstTextManager;
@@ -1341,7 +1340,7 @@ void use_skill(int skill_id)
 void StatsCmd(unsigned char *data, int len)
 {
     int i = 0, c, redraw = 0;
-    sint64 last_exp;
+    gint64 last_exp;
 
     while (i < len) {
         c = data[i++];
@@ -1527,7 +1526,7 @@ void StatsCmd(unsigned char *data, int len)
 void handle_query(char *data, int len)
 {
     char *buf, *cp;
-    uint8 flags = atoi(data);
+    guint8 flags = atoi(data);
 
     (void)len; /* __UNUSED__ */
 
@@ -1646,11 +1645,11 @@ void item_actions(item *op)
  * @param data
  * @param len
  */
-static void common_item_command(uint8 *data, int len)
+static void common_item_command(guint8 *data, int len)
 {
 
     int weight, loc, tag, face, flags, pos = 0, nlen, anim, nrof, type;
-    uint8 animspeed;
+    guint8 animspeed;
     char name[MAX_BUF];
 
     loc = GetInt_String(data);
@@ -1711,10 +1710,10 @@ void Item2Cmd(unsigned char *data, int len)
 void UpdateItemCmd(unsigned char *data, int len)
 {
     int weight, loc, tag, face, sendflags, flags, pos = 0, nlen, anim;
-    uint32 nrof;
+    guint32 nrof;
     char name[MAX_BUF];
     item *ip;
-    uint8 animspeed;
+    guint8 animspeed;
 
     sendflags = data[0];
     pos += 1;
@@ -1775,7 +1774,7 @@ void UpdateItemCmd(unsigned char *data, int len)
         animspeed = data[pos++];
     }
     if (sendflags&UPD_NROF) {
-        nrof = (uint32)GetInt_String(data+pos);
+        nrof = (guint32)GetInt_String(data+pos);
         pos += 4;
     }
     /* update_item calls set_item_values which will then set the list redraw
@@ -1848,8 +1847,8 @@ void DeleteInventory(unsigned char *data, int len)
  */
 void AddspellCmd(unsigned char *data, int len)
 {
-    uint8 nlen;
-    uint16 mlen, pos = 0;
+    guint8 nlen;
+    guint16 mlen, pos = 0;
     Spell *newspell, *tmp;
 
     while (pos < len) {
@@ -1930,14 +1929,9 @@ void AddspellCmd(unsigned char *data, int len)
     cpl.spells_updated = 1;
 }
 
-/**
- *
- * @param data
- * @param len
- */
-void UpdspellCmd(unsigned char *data, int len)
-{
-    int flags, tag, pos = 0;
+void UpdspellCmd(unsigned char *data, int len) {
+    int flags, pos = 0;
+    guint32 tag;
     Spell *tmp;
 
     if (!cpl.spelldata) {
@@ -1973,14 +1967,8 @@ void UpdspellCmd(unsigned char *data, int len)
     cpl.spells_updated = 1;
 }
 
-/**
- *
- * @param data
- * @param len
- */
-void DeleteSpell(unsigned char *data, int len)
-{
-    int tag;
+void DeleteSpell(unsigned char *data, int len) {
+    guint32 tag;
     Spell *tmp, *target;
 
     if (!cpl.spelldata) {
@@ -2062,9 +2050,8 @@ void NewmapCmd(unsigned char *data, int len)
 void Map2Cmd(unsigned char *data, int len)
 {
     int mask, x, y, pos = 0, space_len, value;
-    uint8 type;
+    guint8 type;
 
-    display_map_startupdate();
     /* Not really using map1 protocol, but some draw logic differs from the
      * original draw logic, and map2 is closest.
      */
@@ -2189,7 +2176,6 @@ void map_scrollCmd(char *data, int len)
     buf++;
     dy = atoi(buf);
 
-    display_map_startupdate();
     mapdata_scroll(dx, dy);
     display_map_doneupdate(FALSE, TRUE);
 }
@@ -2219,17 +2205,17 @@ int ExtSmooth(unsigned char *data, int len, int x, int y, int layer)
     y += pl_pos.y;
     newsm = GetChar_String(data);
 
-    if (the_map.cells[x][y].smooth[layer] != newsm) {
+    if (mapdata_cell(x, y)->smooth[layer] != newsm) {
         for (i = 0; i < 8; i++) {
             rx = x+dx[i];
             ry = y+dy[i];
-            if (rx < 0 || ry < 0 || the_map.x <= rx || the_map.y <= ry) {
+            if (!mapdata_contains(rx, ry)) {
                 continue;
             }
-            the_map.cells[x][y].need_resmooth = 1;
+            mapdata_cell(x, y)->need_resmooth = 1;
         }
     }
-    the_map.cells[x][y].smooth[layer] = newsm;
+    mapdata_cell(x, y)->smooth[layer] = newsm;
     return 1;/*Cause smooth infos only use 1 byte*/
 }
 
@@ -2250,9 +2236,6 @@ void MapExtendedCmd(unsigned char *data, int len)
     int entrysize;
     int startpackentry;
 
-    if (!mapupdatesent) {
-        display_map_startupdate();
-    }
     mapupdatesent = 1;
     mask = GetChar_String(data+pos);
     pos += 1;
@@ -2342,13 +2325,12 @@ void MagicMapCmd(unsigned char *data, int len)
         return;
     }
     free(cpl.magicmap);
-    cpl.magicmap = malloc(cpl.mmapx*cpl.mmapy);
+    cpl.magicmap = g_malloc(cpl.mmapx*cpl.mmapy);
     /* Order the server puts it in should be just fine.  Note that the only
      * requirement that this works is that magicmap by 8 bits, being that is
      * the size specified in the protocol and what the server sends us.
      */
     memcpy(cpl.magicmap, cp, cpl.mmapx*cpl.mmapy);
-    cpl.showmagic = 1;
     draw_magic_map();
 }
 
@@ -2372,7 +2354,7 @@ void SinkCmd(unsigned char *data, int len)
  * @param data
  * @param len
  */
-void TickCmd(uint8 *data, int len)
+void TickCmd(guint8 *data, int len)
 {
 
     tick = GetInt_String(data);
@@ -2389,9 +2371,9 @@ void TickCmd(uint8 *data, int len)
  * @param len
  * length of data.
  */
-void PickupCmd(uint8 *data, int len)
+void PickupCmd(guint8 *data, int len)
 {
-    uint32 pickup = GetInt_String(data);
+    guint32 pickup = GetInt_String(data);
     client_pickup(pickup);
 }
 
@@ -2445,9 +2427,7 @@ void FailureCmd(char *buf, int len)
 /**
  * This handles the accountplayers command
  */
-void AccountPlayersCmd(char *buf, int len)
-{
-
+void AccountPlayersCmd(char *buf, int len) {
     int level, pos, flen, faceno;
     char name[MAX_BUF], class[MAX_BUF], race[MAX_BUF],
             face[MAX_BUF], party[MAX_BUF], map[MAX_BUF];
@@ -2522,10 +2502,10 @@ void AccountPlayersCmd(char *buf, int len)
             break;
 
         case ACL_LEVEL:
-            level = GetShort_String(buf+pos+1);
+            level = GetShort_String((unsigned char *)buf + pos + 1);
             break;
         case ACL_FACE_NUM:
-            faceno = GetShort_String(buf+pos+1);
+            faceno = GetShort_String((unsigned char *)buf + pos + 1);
             break;
         }
         pos += flen;
