@@ -12,34 +12,18 @@
  */
 
 /**
- * @file common/mapdata.c
+ * @file
  * Map processing functions.
  */
 
-#include <assert.h>
-#include <stdlib.h>
-
 #include "client.h"
+
+#include <assert.h>
+#include <stdbool.h>
+
 #include "external.h"
 #include "mapdata.h"
 
-/**
- * Clear cells the_map.cells[x][y..y+len_y-1].
- */
-#define CLEAR_CELLS(x, y, len_y) \
-do { \
-    int clear_cells_i, j; \
-    memset(&the_map.cells[(x)][(y)], 0, sizeof(the_map.cells[(x)][(y)])*(len_y)); \
-    for (clear_cells_i = 0; clear_cells_i < (len_y); clear_cells_i++) \
-    { \
-	for (j=0; j < MAXLAYERS; j++) { \
-	    the_map.cells[(x)][(y)+clear_cells_i].heads[j].size_x = 1; \
-	    the_map.cells[(x)][(y)+clear_cells_i].heads[j].size_y = 1; \
-	} \
-    } \
-} while(0)
-
-
 /**
  * Size of virtual map.
  */
@@ -83,17 +67,17 @@ struct BigCell {
     struct MapCellLayer head;
     struct MapCellLayer tail;
 
-    uint16 x, y;
-    uint8 layer;
+    guint16 x, y;
+    guint8 layer;
 };
 
 
 static void recenter_virtual_map_view(int diff_x, int diff_y);
-static void mapdata_get_image_size(int face, uint8 *w, uint8 *h);
+static void mapdata_get_image_size(int face, guint8 *w, guint8 *h);
 
 
 /**
- * Viewable map size.
+ * Viewable map size, in number of tiles.
  */
 static int width, height;
 
@@ -114,6 +98,56 @@ static struct BigCell bigfaces[MAX_VIEW][MAX_VIEW][MAXLAYERS];
 
 struct Map the_map;
 
+/**
+ * Clear cells the_map.cells[x][y..y+len_y-1].
+ */
+static void clear_cells(int x, int y, int len_y) {
+    int clear_cells_i, j;
+    memset(&the_map.cells[(x)][(y)], 0, sizeof(the_map.cells[(x)][(y)])*(len_y));
+
+    for (clear_cells_i = 0; clear_cells_i < (len_y); clear_cells_i++) {
+        for (j=0; j < MAXLAYERS; j++) {
+            the_map.cells[(x)][(y)+clear_cells_i].heads[j].size_x = 1;
+            the_map.cells[(x)][(y)+clear_cells_i].heads[j].size_y = 1;
+        }
+    }
+}
+
+/**
+ * Get the stored map cell at the given map coordinate.
+ */
+struct MapCell *mapdata_cell(int x, int y) {
+    return &the_map.cells[x][y];
+}
+
+/**
+ * Determine whether the map data contains the given cell.
+ */
+bool mapdata_contains(int x, int y) {
+    if (x < 0 || y < 0 || the_map.x <= x || the_map.y <= y) {
+        return false;
+    }
+
+    return true;
+}
+
+bool mapdata_can_smooth(int x, int y, int layer) {
+    return (mapdata_cell(x, y)->heads[layer].face == 0 && layer > 0) ||
+            mapdata_cell(x, y)->smooth[layer];
+}
+
+/**
+ * Determine the size of the internal fog-of-war map.
+ */
+void mapdata_size(int *x, int *y) {
+    if (x != NULL) {
+        *x = the_map.x;
+    }
+
+    if (y != NULL) {
+        *y = the_map.y;
+    }
+}
 
 /**
  * Update darkness information. This function is called whenever a map1a
@@ -125,13 +159,13 @@ struct Map the_map;
  */
 static void set_darkness(int x, int y, int darkness)
 {
-    the_map.cells[x][y].have_darkness = 1;
-    if (the_map.cells[x][y].darkness == darkness) {
+    mapdata_cell(x, y)->have_darkness = 1;
+    if (mapdata_cell(x, y)->darkness == darkness) {
         return;
     }
 
-    the_map.cells[x][y].darkness = darkness;
-    the_map.cells[x][y].need_update = 1;
+    mapdata_cell(x, y)->darkness = darkness;
+    mapdata_cell(x, y)->need_update = 1;
 
     /* pretty ugly - since the light code with pngximage uses neighboring
      * spaces to adjust the darkness, we now need to let the neighbors know
@@ -158,7 +192,7 @@ static void set_darkness(int x, int y, int darkness)
 static void mark_resmooth(int x, int y, int layer)
 {
     int sdx,sdy;
-    if (the_map.cells[x][y].smooth[layer]>1) {
+    if (mapdata_cell(x, y)->smooth[layer]>1) {
         for (sdx=-1; sdx<2; sdx++)
             for (sdy=-1; sdy<2; sdy++)
                 if ( (sdx || sdy) /* ignore (0,0) */
@@ -189,7 +223,7 @@ static void expand_clear_face(int x, int y, int w, int h, int layer)
     assert(0 <= x-w+1 && x-w+1 < FOG_MAP_SIZE);
     assert(0 <= y-h+1 && y-h+1 < FOG_MAP_SIZE);
 
-    cell = &the_map.cells[x][y];
+    cell = mapdata_cell(x, y);
 
     for (dx = 0; dx < w; dx++) {
         for (dy = !dx; dy < h; dy++) {
@@ -239,7 +273,7 @@ static void expand_clear_face_from_layer(int x, int y, int layer)
     assert(0 <= y && y < FOG_MAP_SIZE);
     assert(0 <= layer && layer < MAXLAYERS);
 
-    cell = &the_map.cells[x][y].heads[layer];
+    cell = &mapdata_cell(x, y)->heads[layer];
     if (cell->size_x && cell->size_y) {
         expand_clear_face(x, y, cell->size_x, cell->size_y, layer);
     }
@@ -258,17 +292,17 @@ static void expand_clear_face_from_layer(int x, int y, int layer)
  * we will just overwrite the old data.  Problem with clearing is that
  * clobbers the animation data.
  */
-static void expand_set_face(int x, int y, int layer, sint16 face, int clear)
+static void expand_set_face(int x, int y, int layer, gint16 face, int clear)
 {
     struct MapCell *cell;
     int dx, dy;
-    uint8 w, h;
+    guint8 w, h;
 
     assert(0 <= x && x < FOG_MAP_SIZE);
     assert(0 <= y && y < FOG_MAP_SIZE);
     assert(0 <= layer && layer < MAXLAYERS);
 
-    cell = &the_map.cells[x][y];
+    cell = mapdata_cell(x, y);
 
     if (clear) {
         expand_clear_face_from_layer(x, y, layer);
@@ -409,12 +443,12 @@ static void expand_clear_bigface_from_layer(int x, int y, int layer, int set_nee
  *
  * face is the new face to set.
  */
-static void expand_set_bigface(int x, int y, int layer, sint16 face, int clear)
+static void expand_set_bigface(int x, int y, int layer, gint16 face, int clear)
 {
     struct BigCell *headcell;
     struct MapCellLayer *head;
     int dx, dy;
-    uint8 w, h;
+    guint8 w, h;
 
     assert(0 <= x && x < MAX_VIEW);
     assert(0 <= y && y < MAX_VIEW);
@@ -510,7 +544,7 @@ static void expand_need_update_from_layer(int x, int y, int layer)
     assert(0 <= y && y < FOG_MAP_SIZE);
     assert(0 <= layer && layer < MAXLAYERS);
 
-    head = &the_map.cells[x][y].heads[layer];
+    head = &mapdata_cell(x, y)->heads[layer];
     if (head->face != 0) {
         expand_need_update(x, y, head->size_x, head->size_y);
     } else {
@@ -525,7 +559,7 @@ void mapdata_init(void)
     int i;
 
     if (the_map.cells == NULL) {
-        the_map.cells = malloc(
+        the_map.cells = g_malloc(
                             sizeof(*the_map.cells)*FOG_MAP_SIZE+
                             sizeof(**the_map.cells)*FOG_MAP_SIZE*FOG_MAP_SIZE);
         if (the_map.cells == NULL) {
@@ -554,7 +588,7 @@ void mapdata_init(void)
     pl_pos.y = FOG_MAP_SIZE/2-height/2;
 
     for (x = 0; x < FOG_MAP_SIZE; x++) {
-        CLEAR_CELLS(x, 0, FOG_MAP_SIZE);
+        clear_cells(x, 0, FOG_MAP_SIZE);
     }
 
     for (y = 0; y < MAX_VIEW; y++) {
@@ -577,11 +611,6 @@ void mapdata_init(void)
     bigfaces_head = NULL;
 }
 
-void mapdata_reset(void)
-{
-    mapdata_init();
-}
-
 void mapdata_set_size(int viewx, int viewy)
 {
     mapdata_init();
@@ -618,12 +647,12 @@ void mapdata_clear_space(int x, int y)
         /* tile is visible */
 
         /* visible tile is now blank ==> do not clear but mark as cleared */
-        if (!the_map.cells[px][py].cleared) {
-            the_map.cells[px][py].cleared = 1;
-            the_map.cells[px][py].need_update = 1;
+        if (!mapdata_cell(px, py)->cleared) {
+            mapdata_cell(px, py)->cleared = 1;
+            mapdata_cell(px, py)->need_update = 1;
 
             for (i=0; i < MAXLAYERS; i++)
-                if (the_map.cells[px][py].heads[i].face) {
+                if (mapdata_cell(px, py)->heads[i].face) {
                     expand_need_update_from_layer(px, py, i);
                 }
         }
@@ -661,7 +690,7 @@ void mapdata_set_check_space(int x, int y)
 
 
     is_blank=1;
-    cell = &the_map.cells[px][py];
+    cell = mapdata_cell(px, py);
     for (i=0; i < MAXLAYERS; i++) {
         if (cell->heads[i].face>0 || cell->tails[i].face>0) {
             is_blank=0;
@@ -682,9 +711,9 @@ void mapdata_set_check_space(int x, int y)
         /* tile is visible */
 
         /* visible tile is now blank ==> do not clear but mark as cleared */
-        if (!the_map.cells[px][py].cleared) {
-            the_map.cells[px][py].cleared = 1;
-            the_map.cells[px][py].need_update = 1;
+        if (!mapdata_cell(px, py)->cleared) {
+            mapdata_cell(px, py)->cleared = 1;
+            mapdata_cell(px, py)->need_update = 1;
 
             for (i=0; i < MAXLAYERS; i++) {
                 expand_need_update_from_layer(px, py, i);
@@ -735,7 +764,7 @@ void mapdata_set_smooth(int x, int y, int smooth, int layer)
     assert(0 <= px && px < FOG_MAP_SIZE);
     assert(0 <= py && py < FOG_MAP_SIZE);
 
-    if (the_map.cells[px][py].smooth[layer] != smooth) {
+    if (mapdata_cell(px, py)->smooth[layer] != smooth) {
         for (i=0; i<8; i++) {
             rx=px+dx[i];
             ry=py+dy[i];
@@ -744,8 +773,8 @@ void mapdata_set_smooth(int x, int y, int smooth, int layer)
             }
             the_map.cells[rx][ry].need_resmooth=1;
         }
-        the_map.cells[px][py].need_resmooth=1;
-        the_map.cells[px][py].smooth[layer] = smooth;
+        mapdata_cell(px, py)->need_resmooth=1;
+        mapdata_cell(px, py)->smooth[layer] = smooth;
     }
 }
 
@@ -769,13 +798,13 @@ void mapdata_clear_old(int x, int y)
     assert(0 <= py && py < FOG_MAP_SIZE);
 
     if (x < width && y < height)
-        if (the_map.cells[px][py].cleared) {
+        if (mapdata_cell(px, py)->cleared) {
             for (i=0; i < MAXLAYERS; i++) {
                 expand_clear_face_from_layer(px, py, i);
             }
 
-            the_map.cells[px][py].darkness = 0;
-            the_map.cells[px][py].have_darkness = 0;
+            mapdata_cell(px, py)->darkness = 0;
+            mapdata_cell(px, py)->have_darkness = 0;
         }
 }
 
@@ -783,7 +812,7 @@ void mapdata_clear_old(int x, int y)
  * than take all the faces, takes 1 face and the layer this face is
  * on.  This is used by the Map2Cmd()
  */
-void mapdata_set_face_layer(int x, int y, sint16 face, int layer)
+void mapdata_set_face_layer(int x, int y, gint16 face, int layer)
 {
     int px, py;
 
@@ -796,14 +825,14 @@ void mapdata_set_face_layer(int x, int y, sint16 face, int layer)
     assert(0 <= py && py < FOG_MAP_SIZE);
 
     if (x < width && y < height) {
-        the_map.cells[px][py].need_update = 1;
+        mapdata_cell(px, py)->need_update = 1;
         if (face >0) {
             expand_set_face(px, py, layer, face, TRUE);
         } else {
             expand_clear_face_from_layer(px, py, layer);
         }
 
-        the_map.cells[px][py].cleared = 0;
+        mapdata_cell(px, py)->cleared = 0;
     } else {
         expand_set_bigface(x, y, layer, face, TRUE);
     }
@@ -814,7 +843,7 @@ void mapdata_set_face_layer(int x, int y, sint16 face, int layer)
  * than take all the faces, takes 1 face and the layer this face is
  * on.  This is used by the Map2Cmd()
  */
-void mapdata_set_anim_layer(int x, int y, uint16 anim, uint8 anim_speed, int layer)
+void mapdata_set_anim_layer(int x, int y, guint16 anim, guint8 anim_speed, int layer)
 {
     int px, py;
     int i, face, animation, phase, speed_left;
@@ -832,9 +861,9 @@ void mapdata_set_anim_layer(int x, int y, uint16 anim, uint8 anim_speed, int lay
 
     /* Random animation is pretty easy */
     if ((anim & ANIM_FLAGS_MASK) == ANIM_RANDOM) {
-        phase = random() % animations[animation].num_animations;
+        phase = g_random_int() % animations[animation].num_animations;
         face = animations[animation].faces[phase];
-        speed_left = anim_speed % random();
+        speed_left = anim_speed % g_random_int();
     } else if ((anim & ANIM_FLAGS_MASK) == ANIM_SYNC) {
         animations[animation].speed = anim_speed;
         phase = animations[animation].phase;
@@ -843,26 +872,26 @@ void mapdata_set_anim_layer(int x, int y, uint16 anim, uint8 anim_speed, int lay
     }
 
     if (x < width && y < height) {
-        the_map.cells[px][py].need_update = 1;
-        if (the_map.cells[px][py].cleared) {
+        mapdata_cell(px, py)->need_update = 1;
+        if (mapdata_cell(px, py)->cleared) {
             for (i=0; i < MAXLAYERS; i++) {
                 expand_clear_face_from_layer(px, py, i);
             }
 
-            the_map.cells[px][py].darkness = 0;
-            the_map.cells[px][py].have_darkness = 0;
+            mapdata_cell(px, py)->darkness = 0;
+            mapdata_cell(px, py)->have_darkness = 0;
         }
         if (face >0) {
             expand_set_face(px, py, layer, face, TRUE);
-            the_map.cells[px][py].heads[layer].animation = animation;
-            the_map.cells[px][py].heads[layer].animation_phase = phase;
-            the_map.cells[px][py].heads[layer].animation_speed = anim_speed;
-            the_map.cells[px][py].heads[layer].animation_left = speed_left;
+            mapdata_cell(px, py)->heads[layer].animation = animation;
+            mapdata_cell(px, py)->heads[layer].animation_phase = phase;
+            mapdata_cell(px, py)->heads[layer].animation_speed = anim_speed;
+            mapdata_cell(px, py)->heads[layer].animation_left = speed_left;
         } else {
             expand_clear_face_from_layer(px, py, layer);
         }
 
-        the_map.cells[px][py].cleared = 0;
+        mapdata_cell(px, py)->cleared = 0;
 
     } else {
         expand_set_bigface(x, y, layer, face, TRUE);
@@ -949,9 +978,9 @@ void mapdata_newmap(void)
 
     /* Clear the_map.cells[]. */
     for (x = 0; x < FOG_MAP_SIZE; x++) {
-        CLEAR_CELLS(x, 0, FOG_MAP_SIZE);
+        clear_cells(x, 0, FOG_MAP_SIZE);
         for (y = 0; y < FOG_MAP_SIZE; y++) {
-            the_map.cells[x][y].need_update = 1;
+            mapdata_cell(x, y)->need_update = 1;
         }
     }
 
@@ -959,34 +988,68 @@ void mapdata_newmap(void)
     while (bigfaces_head != NULL) {
         expand_clear_bigface_from_layer(bigfaces_head->x, bigfaces_head->y, bigfaces_head->layer, 0);
     }
-
-    display_map_newmap();
 }
 
-sint16 mapdata_face(int x, int y, int layer)
-{
-    if (width <= 0) {
-        return(0);
+/**
+ * Check if the given map tile is a valid slot in the map array.
+ */
+static bool mapdata_has_tile(int x, int y, int layer) {
+    if (0 <= x && x < width && 0 <= y && y < height) {
+        if (0 <= layer && layer < MAXLAYERS) {
+            return true;
+        }
     }
 
-    assert(0 <= x && x < width);
-    assert(0 <= y && y < height);
-    assert(0 <= layer && layer < MAXLAYERS);
-
-    return(the_map.cells[pl_pos.x+x][pl_pos.y+y].heads[layer].face);
+    return false;
 }
 
-sint16 mapdata_bigface(int x, int y, int layer, int *ww, int *hh)
-{
-    sint16 result;
-
-    if (width <= 0) {
-        return(0);
+/**
+ * Return the face number of a single-square pixmap at the given map tile.
+ * @param x X-coordinate of tile on-screen
+ * @param y Y-coordinate of tile on-screen
+ * @param layer
+ * @return Pixmap face number, or zero if the tile does not exist
+ */
+gint16 mapdata_face(int x, int y, int layer) {
+    if (!mapdata_has_tile(x, y, layer)) {
+        return 0;
     }
 
-    assert(0 <= x && x < width);
-    assert(0 <= y && y < height);
-    assert(0 <= layer && layer < MAXLAYERS);
+    return the_map.cells[pl_pos.x+x][pl_pos.y+y].heads[layer].face;
+}
+
+gint16 mapdata_face_info(int mx, int my, int layer, int *dx, int *dy) {
+    struct MapCellLayer *head = &the_map.cells[mx][my].heads[layer];
+    struct MapCellLayer *tail = &the_map.cells[mx][my].tails[layer];
+    if (head->face != 0) {
+        const int width = head->size_x, height = head->size_y;
+        *dx = 1 - width, *dy = 1 - height;
+        return head->face;
+    } else if (tail->face != 0) {
+        struct MapCellLayer *head_ptr = &the_map.cells[mx + tail->size_x][my + tail->size_y].heads[layer];
+        const int width = head_ptr->size_x, height = head_ptr->size_y;
+        *dx = tail->size_x - width + 1, *dy = tail->size_y - height + 1;
+        return tail->face;
+    } else {
+        return 0;
+    }
+}
+
+/**
+ * Return the face number of a multi-square pixmap at the given map tile.
+ * @param x X-coordinate of tile on-screen
+ * @param y Y-coordinate of tile on-screen
+ * @param layer
+ * @param ww
+ * @param hh
+ * @return Pixmap face number, or zero if the tile does not exist
+ */
+gint16 mapdata_bigface(int x, int y, int layer, int *ww, int *hh) {
+    gint16 result;
+
+    if (!mapdata_has_tile(x, y, layer)) {
+        return 0;
+    }
 
     result = the_map.cells[pl_pos.x+x][pl_pos.y+y].tails[layer].face;
     if (result != 0) {
@@ -1062,18 +1125,13 @@ sint16 mapdata_bigface(int x, int y, int layer, int *ww, int *hh)
  * otherwise, returns 0 - we don't care about the tails
  * or other details really.
  */
-sint16 mapdata_bigface_head(int x, int y, int layer, int *ww, int *hh)
-{
-    sint16 result;
+gint16 mapdata_bigface_head(int x, int y, int layer, int *ww, int *hh) {
+    gint16 result;
 
-    if (width <= 0) {
-        return(0);
+    if (!mapdata_has_tile(x, y, layer)) {
+        return 0;
     }
 
-    assert(0 <= x && x < MAX_VIEW);
-    assert(0 <= y && y < MAX_VIEW);
-    assert(0 <= layer && layer < MAXLAYERS);
-
     result = bigfaces[x][y][layer].head.face;
     if (result != 0) {
         int w = bigfaces[x][y][layer].head.size_x;
@@ -1174,7 +1232,7 @@ static void recenter_virtual_map_view(int diff_x, int diff_y)
     if (shift_x <= -FOG_MAP_SIZE || shift_x >= FOG_MAP_SIZE
             || shift_y <= -FOG_MAP_SIZE || shift_y >= FOG_MAP_SIZE) {
         for (dx = 0; dx < FOG_MAP_SIZE; dx++) {
-            CLEAR_CELLS(dx, 0, FOG_MAP_SIZE);
+            clear_cells(dx, 0, FOG_MAP_SIZE);
         }
 
         pl_pos.x = FOG_MAP_SIZE/2-width/2;
@@ -1233,18 +1291,18 @@ static void recenter_virtual_map_view(int diff_x, int diff_y)
 
     /* Clear newly opened area */
     for (dx = 0; dx < dst_x; dx++) {
-        CLEAR_CELLS(dx, 0, FOG_MAP_SIZE);
+        clear_cells(dx, 0, FOG_MAP_SIZE);
     }
     for (dx = dst_x+len_x; dx < FOG_MAP_SIZE; dx++) {
-        CLEAR_CELLS(dx, 0, FOG_MAP_SIZE);
+        clear_cells(dx, 0, FOG_MAP_SIZE);
     }
     if (shift_y > 0) {
         for (dx = 0; dx < len_x; dx++) {
-            CLEAR_CELLS(dx+dst_x, 0, shift_y);
+            clear_cells(dx+dst_x, 0, shift_y);
         }
     } else if (shift_y < 0) {
         for (dx = 0; dx < len_x; dx++) {
-            CLEAR_CELLS(dx+dst_x, FOG_MAP_SIZE+shift_y, -shift_y);
+            clear_cells(dx+dst_x, FOG_MAP_SIZE+shift_y, -shift_y);
         }
     }
 }
@@ -1253,7 +1311,7 @@ static void recenter_virtual_map_view(int diff_x, int diff_y)
  * Return the size of a face in tiles. The returned size is at between 1 and
  * MAX_FACE_SIZE (inclusive).
  */
-static void mapdata_get_image_size(int face, uint8 *w, uint8 *h)
+static void mapdata_get_image_size(int face, guint8 *w, guint8 *h)
 {
     get_map_image_size(face, w, h);
     if (*w < 1) {
