@@ -11,14 +11,8 @@
  * The authors can be reached via e-mail at <crossfire@metalforge.org>.
  */
 
-/*
- * This file has its own script.h for prototypes, so don't want to include
- * this when doing a 'make proto'.
- */
-#ifndef CPROTO
-
 /**
- * @file common/script.c
+ * @file
  * Handles the client-side scripting interface.
  *
  * Each script is an external process that keeps two pipes open between the
@@ -102,6 +96,10 @@
  * This does not work under Windows for now.  Someday this will be fixed :)
  */
 
+#include "client.h"
+
+#include <ctype.h>
+
 #ifndef WIN32
 #include <errno.h>
 #include <sys/types.h>
@@ -110,13 +108,11 @@
 /* for SIGHUP */
 #include <signal.h>
 #endif
-#include <ctype.h>
 
-#include <client.h>
-#include <external.h>
-#include <script.h>
-#include <p_cmd.h>
+#include "external.h"
 #include "mapdata.h"
+#include "p_cmd.h"
+#include "script.h"
 
 /*
  * Data structures
@@ -265,7 +261,7 @@ void script_init(const char *cparams) {
 
     /* Child--set stdin/stdout to the pipes, then exec */
     if (pid == 0) {
-        int i;
+        size_t i;
         int r;
         char *argv[256];
 
@@ -323,8 +319,8 @@ void script_init(const char *cparams) {
         LOG(LOG_WARNING, "common::script_init", "Error on fcntl.");
     }
 
-    /* realloc script array to add new entry; fill in the data */
-    scripts = realloc(scripts, sizeof(scripts[0])*(num_scripts+1));
+    /* g_realloc script array to add new entry; fill in the data */
+    scripts = g_realloc(scripts, sizeof(scripts[0])*(num_scripts+1));
 
     if (scripts == NULL) {
         LOG(LOG_ERROR, "script_init",
@@ -332,8 +328,8 @@ void script_init(const char *cparams) {
         exit(EXIT_FAILURE);
     }
 
-    scripts[num_scripts].name = strdup(name);
-    scripts[num_scripts].params = args ? strdup(args) : NULL;
+    scripts[num_scripts].name = g_strdup(name);
+    scripts[num_scripts].params = args ? g_strdup(args) : NULL;
     scripts[num_scripts].out_fd = pipe1[1];
     scripts[num_scripts].in_fd = pipe2[0];
     scripts[num_scripts].monitor = 0;
@@ -453,8 +449,8 @@ void script_init(const char *cparams) {
         return;
     }
 
-    /* realloc script array to add new entry; fill in the data */
-    scripts = realloc(scripts, sizeof(scripts[0])*(num_scripts+1));
+    /* g_realloc script array to add new entry; fill in the data */
+    scripts = g_realloc(scripts, sizeof(scripts[0])*(num_scripts+1));
 
     if (scripts == NULL) {
         LOG(LOG_ERROR, "script_init",
@@ -462,8 +458,8 @@ void script_init(const char *cparams) {
         exit(EXIT_FAILURE);
     }
 
-    scripts[num_scripts].name = strdup(name);
-    scripts[num_scripts].params = args ? strdup(args) : NULL;
+    scripts[num_scripts].name = g_strdup(name);
+    scripts[num_scripts].params = args ? g_strdup(args) : NULL;
     scripts[num_scripts].out_fd = hChildStdinWrDup;
     scripts[num_scripts].in_fd = hChildStdoutRdDup;
     scripts[num_scripts].monitor = 0;
@@ -621,12 +617,12 @@ void script_process(fd_set *set)
     }
 }
 
-void script_watch(const char *cmd, const uint8 *data_initial, const int data_len, const enum CmdFormat format)
+void script_watch(const char *cmd, const guint8 *data_initial, const int data_len, const enum CmdFormat format)
 {
     int i;
     int w;
     int l, len;
-    const uint8 *data;
+    const guint8 *data;
 
     /* For each script... */
     for (i = 0; i < num_scripts; ++i) {
@@ -695,7 +691,7 @@ void script_watch(const char *cmd, const uint8 *data_initial, const int data_len
                                 data += 2;
                                 len -= 2;
                             } else if (c >= CS_STAT_SKILLINFO && c < (CS_STAT_SKILLINFO+CS_NUM_SKILLS)) {
-                                be += snprintf(buf+be, sizeof(buf)-be, " skill %d %d %" FMT64 "\n", c, *data, GetInt64_String(data+1));
+                                be += snprintf(buf+be, sizeof(buf)-be, " skill %d %d %" G_GINT64_FORMAT "\n", c, *data, GetInt64_String(data+1));
                                 data += 9;
                                 len -= 9;
                             } else
@@ -785,7 +781,7 @@ void script_watch(const char *cmd, const uint8 *data_initial, const int data_len
                                     break;
 
                                 case CS_STAT_EXP64:
-                                    be += snprintf(buf+be, sizeof(buf)-be, " exp %" FMT64 "\n", GetInt64_String(data));
+                                    be += snprintf(buf+be, sizeof(buf)-be, " exp %" G_GINT64_FORMAT "\n", GetInt64_String(data));
                                     data += 8;
                                     len -= 8;
                                     break;
@@ -1054,48 +1050,49 @@ static void send_map(int i, int x, int y)
 {
     char buf[1024];
 
-    if (x < 0 || y < 0 || the_map.x <= x || the_map.y <= y) {
+    if (!mapdata_contains(x, y)) {
         snprintf(buf, sizeof(buf), "request map %d %d unknown\n", x, y);
         write(scripts[i].out_fd, buf, strlen(buf));
     }
     /*** FIXME *** send more relevant data ***/
     snprintf(buf, sizeof(buf), "request map %d %d  %d %c %c %c %c"
              " smooth %d %d %d heads %d %d %d tails %d %d %d\n",
-             x, y, the_map.cells[x][y].darkness,
-             the_map.cells[x][y].need_update ? 'y' : 'n',
-             the_map.cells[x][y].have_darkness ? 'y' : 'n',
-             the_map.cells[x][y].need_resmooth ? 'y' : 'n',
-             the_map.cells[x][y].cleared ? 'y' : 'n',
-             the_map.cells[x][y].smooth[0], the_map.cells[x][y].smooth[1], the_map.cells[x][y].smooth[2],
-             the_map.cells[x][y].heads[0].face, the_map.cells[x][y].heads[1].face, the_map.cells[x][y].heads[2].face,
-             the_map.cells[x][y].tails[0].face, the_map.cells[x][y].tails[1].face, the_map.cells[x][y].tails[2].face
+             x, y, mapdata_cell(x, y)->darkness,
+             mapdata_cell(x, y)->need_update ? 'y' : 'n',
+             mapdata_cell(x, y)->have_darkness ? 'y' : 'n',
+             mapdata_cell(x, y)->need_resmooth ? 'y' : 'n',
+             mapdata_cell(x, y)->cleared ? 'y' : 'n',
+             mapdata_cell(x, y)->smooth[0], mapdata_cell(x, y)->smooth[1], mapdata_cell(x, y)->smooth[2],
+             mapdata_cell(x, y)->heads[0].face, mapdata_cell(x, y)->heads[1].face, mapdata_cell(x, y)->heads[2].face,
+             mapdata_cell(x, y)->tails[0].face, mapdata_cell(x, y)->tails[1].face, mapdata_cell(x, y)->tails[2].face
             );
     write(scripts[i].out_fd, buf, strlen(buf));
 }
 
-static void script_process_cmd(int i)
-{
+/**
+ * Process a single script command from the given script. This function
+ * removes the processed command from the buffer when finished.
+ * @param i Index of the script to process a command from
+ */
+static void script_process_cmd(int i) {
     char cmd[1024];
     char *c;
-    int l;
 
-    /*
-     * Strip out just this one command
-     */
-    for (l = 0; l < scripts[i].cmd_count; ++l) {
-        if (scripts[i].cmd[l] == '\n') {
-            break;
-        }
+    // Find the length of the command up to the trailing newline.
+    int l = strcspn(scripts[i].cmd, "\n") + 1;
+
+    // Copy a single command up until the newline into a buffer.
+    g_strlcpy(cmd, scripts[i].cmd, l);
+
+    // If a carriage return is present, trim it out as well.
+    char *cr = strchr(cmd, '\r');
+    if (cr != NULL) {
+        *cr = '\0';
     }
-    ++l;
-    memcpy(cmd, scripts[i].cmd, l);
-#ifndef WIN32
-    cmd[l-1] = 0;
-#else
-    cmd[l-2] = 0;
-#endif
+
+    // Remove a single command from the script command buffer.
     if (l < scripts[i].cmd_count) {
-        memmove(scripts[i].cmd, scripts[i].cmd+l, scripts[i].cmd_count-l);
+        memmove(scripts[i].cmd, scripts[i].cmd + l, scripts[i].cmd_count - l);
         scripts[i].cmd_count -= l;
     } else {
         scripts[i].cmd_count = 0;
@@ -1139,8 +1136,8 @@ static void script_process_cmd(int i)
         while (*c == ' ') {
             ++c;
         }
-        c = strdup(c);
-        scripts[i].watch = realloc(scripts[i].watch, (scripts[i].num_watch+1)*sizeof(scripts[i].watch[1]));
+        c = g_strdup(c);
+        scripts[i].watch = g_realloc(scripts[i].watch, (scripts[i].num_watch+1)*sizeof(scripts[i].watch[1]));
         scripts[i].watch[scripts[i].num_watch] = c;
         ++scripts[i].num_watch;
     } else if (strncmp(cmd, "unwatch", 7) == 0) {
@@ -1255,10 +1252,10 @@ static void script_process_cmd(int i)
                 char buf[1024];
                 int s;
 
-                snprintf(buf, sizeof(buf), "request stat xp %d %" FMT64, cpl.stats.level, cpl.stats.exp);
+                snprintf(buf, sizeof(buf), "request stat xp %d %" G_GINT64_FORMAT, cpl.stats.level, cpl.stats.exp);
                 write(scripts[i].out_fd, buf, strlen(buf));
                 for (s = 0; s < MAX_SKILL; ++s) {
-                    snprintf(buf, sizeof(buf), " %d %" FMT64, cpl.stats.skill_level[s], cpl.stats.skill_exp[s]);
+                    snprintf(buf, sizeof(buf), " %d %" G_GINT64_FORMAT, cpl.stats.skill_level[s], cpl.stats.skill_exp[s]);
                     write(scripts[i].out_fd, buf, strlen(buf));
                 }
                 write(scripts[i].out_fd, "\n", 1);
@@ -1377,14 +1374,18 @@ static void script_process_cmd(int i)
                                  y+pl_pos.y+use_config[CONFIG_MAPHEIGHT]/2-1
                                 );
             } else if (strncmp(c, "all", 3) == 0) {
-                char buf[1024];
+                char *endmsg = "request map end\n";
+                int sizex, sizey;
 
-                for (y = 0; y < the_map.y; ++y)
-                    for (x = 0; x < the_map.x; ++x) {
+                mapdata_size(&sizex, &sizey);
+
+                for (y = 0; y < sizey; y++) {
+                    for (x = 0; x < sizex; x++) {
                         send_map(i, x, y);
                     }
-                snprintf(buf, sizeof(buf), "request map end\n");
-                write(scripts[i].out_fd, buf, strlen(buf));
+                }
+
+                write(scripts[i].out_fd, endmsg, strlen(endmsg));
             } else {
                 while (*c && !isdigit(*c)) {
                     ++c;
@@ -1411,24 +1412,24 @@ static void script_process_cmd(int i)
 
             for (s = 0; s < CS_NUM_SKILLS; s++) {
                 if (skill_names[s]) {
-                    sprintf(buf, "request skills %d %s\n", CS_STAT_SKILLINFO + s, skill_names[s]);
+                    snprintf(buf, sizeof(buf), "request skills %d %s\n", CS_STAT_SKILLINFO + s, skill_names[s]);
                     write(scripts[i].out_fd, buf, strlen(buf));
                 }
             }
-            sprintf(buf, "request skills end\n");
+            snprintf(buf, sizeof(buf), "request skills end\n");
             write(scripts[i].out_fd, buf, strlen(buf));
         } else if (strncmp(c, "spells", 6) == 0) {
             char buf[1024];
             Spell *spell;
 
             for (spell = cpl.spelldata; spell; spell = spell->next) {
-                sprintf(buf, "request spells %d %d %d %d %d %d %d %d %s\n",
+                snprintf(buf, sizeof(buf), "request spells %d %d %d %d %d %d %d %d %s\n",
                         spell->tag, spell->level, spell->sp, spell->grace,
                         spell->skill_number, spell->path, spell->time,
                         spell->dam, spell->name);
                 write(scripts[i].out_fd, buf, strlen(buf));
             }
-            sprintf(buf, "request spells end\n");
+            snprintf(buf, sizeof(buf), "request spells end\n");
             write(scripts[i].out_fd, buf, strlen(buf));
         } else {
             char buf[1024];
@@ -1495,7 +1496,7 @@ static void script_process_cmd(int i)
             if (strncmp(c, "mark", 4) == 0) {
                 int tag;
                 SockList sl;
-                uint8 buf[MAX_BUF];
+                guint8 buf[MAX_BUF];
 
                 c += 4;
 
@@ -1514,7 +1515,7 @@ static void script_process_cmd(int i)
             } else if (strncmp(c, "lock", 4) == 0) {
                 int tag, locked;
                 SockList sl;
-                uint8 buf[MAX_BUF];
+                guint8 buf[MAX_BUF];
 
                 c += 4;
 
@@ -1636,5 +1637,3 @@ static void script_send_item(int i, const char *head, const item *it)
     snprintf(buf, sizeof(buf), "%s%d %d %d %d %d %s\n", head, it->tag, it->nrof, (int)(it->weight*1000+0.5), flags, it->type, it->d_name);
     write(scripts[i].out_fd, buf, strlen(buf));
 }
-
-#endif /* CPROTO */
