@@ -12,31 +12,30 @@
  */
 
 /**
- * @file gtk-v2/src/account.c
- * Handles account login, creation, and character selection.
+ * @file
+ * Handle account creation, login, and character selection
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <gtk/gtk.h>
-#include <ctype.h>
-
 #include "client.h"
+
+#include <ctype.h>
+#include <gtk/gtk.h>
+
 #include "image.h"
 #include "main.h"
-#include "gtk2proto.h"
 #include "metaserver.h"
+#include "gtk2proto.h"
+
+#ifdef WIN32
+# include "script.h"
+#endif
 
 static GtkWidget *add_character_window, *choose_char_window,
        *create_account_window, *login_window, *account_password_window;
 
 /* These are in the login_window */
-static GtkWidget *button_login, *button_create_account,
-       *button_go_metaserver, *button_exit_client,
-       *entry_account_name,
-       *entry_account_password, *label_account_login_status;
+static GtkWidget *button_login, *button_create_account, *button_go_metaserver,
+    *entry_account_name, *entry_account_password, *label_account_login_status;
 
 /* These are in the create_account_window */
 static GtkWidget *button_new_create_account, *button_new_cancel,
@@ -162,7 +161,7 @@ void create_new_character_failure(char *message) {
 
 static void create_new_character() {
     const char *name;
-    uint8 buf[MAX_BUF];
+    guint8 buf[MAX_BUF];
     SockList sl;
 
     SockList_Init(&sl, buf);
@@ -259,7 +258,7 @@ static void init_new_character_window() {
 static void add_character_to_account(const char *name, const char *password,
                                      int force) {
     SockList sl;
-    uint8 buf[MAX_BUF];
+    guint8 buf[MAX_BUF];
 
     if (!name || !password || *name == 0 || *password == 0) {
         gtk_label_set_text(GTK_LABEL(label_add_status),
@@ -465,7 +464,7 @@ void choose_char_window_show() {
  */
 static void play_character(const char *name) {
     SockList sl;
-    uint8 buf[MAX_BUF];
+    guint8 buf[MAX_BUF];
 
     SockList_Init(&sl, buf);
     SockList_AddString(&sl, "accountplay ");
@@ -492,6 +491,7 @@ on_button_play_character_clicked(GtkButton *button, gpointer user_data) {
     if (gtk_tree_selection_get_selected(selected, &model, &iter)) {
         gtk_tree_model_get(model, &iter, CHAR_NAME, &name, -1);
 
+        hide_all_login_windows();
         play_character(name);
     }
 }
@@ -605,40 +605,6 @@ void update_character_choose(const char *name, const char *class,
     }
 }
 
-/**
- * User has double clicked one of the character rows, so use that character as
- * the one to play.
- *
- * @param treeview  Treeview which activated that (should always be
- *                  treeview_choose_character)
- * @param path      Mechanism to get to selected entry
- * @param column    Activated column?
- * @param user_data Not set
- */
-void on_treeview_choose_character_activated(GtkTreeView       *treeview,
-        GtkTreePath       *path,
-        GtkTreeViewColumn *column,
-        gpointer          user_data) {
-    GtkTreeIter iter;
-    GtkTreeModel    *model;
-    char *name;
-
-    model = gtk_tree_view_get_model(treeview);
-    if (gtk_tree_model_get_iter(model, &iter, path)) {
-        gtk_tree_model_get(model, &iter, CHAR_NAME, &name, -1);
-
-        if (!name) {
-            LOG(LOG_ERROR, "account.c::on_treeview_choose_character_activated",
-                "unable to get character name");
-            return;
-        }
-        play_character(name);
-    }
-}
-
-/**
- *
- */
 static void init_choose_char_window() {
     GtkTextIter end;
     GtkCellRenderer *renderer;
@@ -692,7 +658,7 @@ static void init_choose_char_window() {
     g_signal_connect((gpointer) button_account_password, "clicked",
                      G_CALLBACK(on_button_account_password_clicked), NULL);
     g_signal_connect((gpointer) treeview_choose_character, "row_activated",
-                     G_CALLBACK(on_treeview_choose_character_activated), NULL);
+                     G_CALLBACK(on_button_play_character_clicked), NULL);
 
     character_store = gtk_list_store_new(CHAR_NUM_COLUMNS,
                                          G_TYPE_STRING, G_TYPE_STRING,
@@ -775,7 +741,7 @@ void account_creation_failure(char *message) {
 static void do_account_create(const char *name, const char *p1,
                               const char *p2) {
     SockList sl;
-    uint8 buf[MAX_BUF];
+    guint8 buf[MAX_BUF];
 
     if (strcmp(p1, p2)) {
         gtk_label_set_text(GTK_LABEL(label_create_account_status),
@@ -970,13 +936,7 @@ on_button_create_account_clicked(GtkButton *button, gpointer user_data) {
  */
 void
 on_button_go_metaserver_clicked(GtkButton *button, gpointer user_data) {
-    close_server_connection();
-
-    if (csocket_fd) {
-        gdk_input_remove(csocket_fd);
-        csocket_fd = 0;
-        gtk_main_quit();
-    }
+    client_disconnect();
 }
 
 /**
@@ -984,8 +944,7 @@ on_button_go_metaserver_clicked(GtkButton *button, gpointer user_data) {
  * @param button
  * @param user_data
  */
-void
-on_button_exit_client_clicked(GtkButton *button, gpointer user_data) {
+void on_button_exit_client_clicked(GtkButton *button, gpointer user_data) {
 #ifdef WIN32
     script_killall();
 #endif
@@ -1001,7 +960,7 @@ on_button_exit_client_clicked(GtkButton *button, gpointer user_data) {
  */
 static void do_account_login(const char *name, const char *password) {
     SockList sl;
-    uint8 buf[MAX_BUF];
+    guint8 buf[MAX_BUF];
 
     if (!name || !password || *name == 0 || *password == 0) {
         gtk_label_set_text(GTK_LABEL(label_account_login_status),
@@ -1033,41 +992,12 @@ on_button_login_clicked(GtkButton *button, gpointer user_data) {
 }
 
 /**
- * User hit return in the name entry box.  If there is data in the password
- * box, attempt login, otherwise make the password box active.
+ * User hit return in the name entry box.
  * @param entry
  * @param user_data
  */
-void
-on_entry_account_name_activate(GtkEntry *entry, gpointer user_data) {
-    const char *password;
-
-    password = gtk_entry_get_text(GTK_ENTRY(entry_account_password));
-
-    if (!password || *password == 0) {
-        gtk_widget_grab_focus(entry_account_password);
-    } else {
-        do_account_login(gtk_entry_get_text(GTK_ENTRY(entry_account_name)), password);
-    }
-}
-
-/**
- * user hit return in the password box.  Like above, if name data, do login,
- * otherwise make the name box active.
- * @param entry
- * @param user_data
- */
-void
-on_entry_account_password_activate(GtkEntry *entry, gpointer user_data) {
-    const char *name;
-
-    name = gtk_entry_get_text(GTK_ENTRY(entry_account_name));
-
-    if (!name || *name == 0) {
-        gtk_widget_grab_focus(entry_account_name);
-    } else {
-        do_account_login(name, gtk_entry_get_text(GTK_ENTRY(entry_account_password)));
-    }
+void on_entry_account_name_activate(GtkEntry* entry, gpointer user_data) {
+    gtk_widget_grab_focus(entry_account_password);
 }
 
 /**
@@ -1078,23 +1008,22 @@ static void init_login_window() {
     GtkTextIter end;
 
     login_window = GTK_WIDGET(gtk_builder_get_object(dialog_xml, "login_window"));
-
     if (!login_window) {
         error_dialog("Failed to open dialogs.", "Did you run `make install`?");
         exit(1);
     }
 
+    g_signal_connect(login_window, "delete_event",
+                     G_CALLBACK(on_button_exit_client_clicked), NULL);
+
     gtk_window_set_transient_for(
         GTK_WINDOW(login_window), GTK_WINDOW(window_root));
-
     button_login =
         GTK_WIDGET(gtk_builder_get_object(dialog_xml, "button_login"));
     button_create_account =
         GTK_WIDGET(gtk_builder_get_object(dialog_xml, "button_create_account"));
     button_go_metaserver =
         GTK_WIDGET(gtk_builder_get_object(dialog_xml, "button_go_metaserver"));
-    button_exit_client =
-        GTK_WIDGET(gtk_builder_get_object(dialog_xml, "button_exit_client"));
     label_account_login_status =
         GTK_WIDGET(gtk_builder_get_object(dialog_xml, "label_account_login_status"));
     login_pane[TEXTVIEW_MOTD].textview =
@@ -1134,16 +1063,13 @@ static void init_login_window() {
                      G_CALLBACK(on_window_delete_event), NULL);
     g_signal_connect((gpointer) entry_account_name, "activate",
                      G_CALLBACK(on_entry_account_name_activate), NULL);
-    g_signal_connect((gpointer) entry_account_password, "activate",
-                     G_CALLBACK(on_entry_account_password_activate), NULL);
+    // entry_account_password is the default action in GtkBuilder
     g_signal_connect((gpointer) button_login, "clicked",
                      G_CALLBACK(on_button_login_clicked), NULL);
     g_signal_connect((gpointer) button_create_account, "clicked",
                      G_CALLBACK(on_button_create_account_clicked), NULL);
     g_signal_connect((gpointer) button_go_metaserver, "clicked",
                      G_CALLBACK(on_button_go_metaserver_clicked), NULL);
-    g_signal_connect((gpointer) button_exit_client, "clicked",
-                     G_CALLBACK(on_button_exit_client_clicked), NULL);
 }
 
 /*****************************************************************************
@@ -1164,7 +1090,7 @@ static void init_login_window() {
  */
 static void do_account_change(const char *old, const char *p1, const char *p2) {
     SockList sl;
-    uint8 buf[MAX_BUF];
+    guint8 buf[MAX_BUF];
 
     if (strcmp(p1, p2)) {
         gtk_label_set_text(GTK_LABEL(label_account_password_status),
@@ -1330,7 +1256,7 @@ void update_login_info(int type) {
              */
             char *mynews, *cp, *el, big_buf[BIG_BUF], *cp1;
 
-            mynews = strdup(news);
+            mynews = g_strdup(news);
             /* We basically work from the end of the string going towards the
              * start looking for % characters.  If we find one, we have to
              * make sure it is at the start of the line or start of the buffer
