@@ -12,22 +12,18 @@
  */
 
 /**
- * @file gtk-v2/src/create_char.c
- * Handles creation of new characters
+ * @file
+ * Handle new character creation
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "client.h"
 
-#include <ctype.h>
 #include <gtk/gtk.h>
 
-#include "client.h"
 #include "image.h"
 #include "main.h"
-#include "gtk2proto.h"
 #include "metaserver.h"
+#include "gtk2proto.h"
 
 /* This corresponds to the number of opt_.. fields in the
  * create_character_window.  In theory, the vbox could be resized
@@ -239,12 +235,12 @@ static void update_all_stats()
             negative_stat = 1;
         }
 
-        sprintf(buf, "%d", statval);
+        snprintf(buf, sizeof(buf), "%d", statval);
         gtk_label_set_text(GTK_LABEL(label_tot[i]), buf);
     }
 
     tmp = stat_points - stat_points_used;
-    sprintf(buf,"%d", tmp);
+    snprintf(buf, sizeof(buf), "%d", tmp);
     gtk_label_set_text(GTK_LABEL(label_cc_unspent), buf);
 
     /* Display some warning messages - we could try and display all the
@@ -271,7 +267,7 @@ static void send_create_player_to_server()
     int i, on_choice, tmp;
     SockList sl;
     char buf[MAX_BUF];
-    uint8 sockbuf[MAX_BUF];
+    guint8 sockbuf[MAX_BUF];
 
     char_name = gtk_entry_get_text(GTK_ENTRY(entry_new_character_name));
 
@@ -601,7 +597,8 @@ on_combobox_rcs_changed(GtkComboBox *box, gpointer user_data)
         }
         gtk_combo_box_set_active(GTK_COMBO_BOX(opt_combobox[i+opt_start]), 0);
 
-        gtk_label_set(GTK_LABEL(opt_label[i+opt_start]), rc->rc_choice[i].choice_desc);
+        gtk_label_set_text(GTK_LABEL(opt_label[i + opt_start]),
+                           rc->rc_choice[i].choice_desc);
         gtk_widget_show(opt_label[i+opt_start]);
         gtk_widget_show(opt_combobox[i+opt_start]);
         /* No signals are connected - the value of the combo
@@ -620,7 +617,7 @@ on_combobox_rcs_changed(GtkComboBox *box, gpointer user_data)
      * at either the race or class to get values from.
      */
     for (i=0; i < NUM_NEW_CHAR_STATS; i++) {
-        sprintf(buf, "%+d", rc->stat_adj[stat_mapping[i].rc_offset]);
+        snprintf(buf, sizeof(buf), "%+d", rc->stat_adj[stat_mapping[i].rc_offset]);
         gtk_label_set_text(GTK_LABEL(label_stat[i]), buf);
     }
     update_all_stats();
@@ -650,7 +647,7 @@ void new_char_window_update_info()
 
     gtk_label_set_text(GTK_LABEL(label_cc_status_update), "Waiting for player selections");
 
-    sprintf(buf,"%d", stat_points);
+    snprintf(buf, sizeof(buf), "%d", stat_points);
     gtk_label_set_text(GTK_LABEL(label_cc_unspent), buf);
 
     /* Set up the races combobox */
