@@ -12,40 +12,21 @@
  */
 
 /**
- * @file gtk-v2/src/image.c
+ * @file
  * Contains highlevel image related functions and mostly deals with the image
  * caching, processing the image commands from the server, etc.  It is
  * gtk-specific as it returns gtk pixmaps.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "client.h"
 
-#include <png.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-
-#ifndef WIN32
-#include <unistd.h>
-#endif
-
-/* Pick up the gtk headers we need */
 #include <gtk/gtk.h>
-#ifndef WIN32
-#include <gdk/gdkx.h>
-#else
-#include <gdk/gdkwin32.h>
-#endif
-#include <gdk/gdkkeysyms.h>
 
 #ifdef HAVE_SDL
 #include <SDL.h>
 #include <SDL_image.h>
 #endif
 
-#include "client-types.h"
-#include "client.h"
 #include "image.h"
 #include "main.h"
 #include "mapdata.h"
@@ -56,9 +37,9 @@ int image_size=DEFAULT_IMAGE_SIZE;
 
 struct {
     char    *name;
-    uint32  checksum;
-    uint8   *png_data;
-    uint32  width, height;
+    guint32  checksum;
+    guint8   *png_data;
+    guint32  width, height;
 } private_cache[MAXPIXMAPNUM];
 
 #define BPP 4
@@ -114,18 +95,10 @@ typedef struct Keys {
 
 /**
  * Helper function to make the code more readable
- *
- * @param data
- * @param pi
- * @param pixmap_num
  */
-static void create_icon_image(uint8 *data, PixmapInfo *pi, int pixmap_num)
-{
+static void create_icon_image(guint8 *data, PixmapInfo *pi) {
     pi->icon_mask = NULL;
-    if (rgba_to_gdkpixbuf(data, pi->icon_width, pi->icon_height,
-                          (GdkPixbuf**)&pi->icon_image)) {
-        LOG (LOG_ERROR,"gtk-v2::create_icon_image","Unable to create scaled image, dest num = %d\n", pixmap_num);
-    }
+    pi->icon_image = rgba_to_gdkpixbuf(data, pi->icon_width, pi->icon_height);
 }
 
 /**
@@ -134,8 +107,7 @@ static void create_icon_image(uint8 *data, PixmapInfo *pi, int pixmap_num)
  * @param data
  * @param pi
  */
-static void create_map_image(uint8 *data, PixmapInfo *pi)
-{
+static void create_map_image(guint8 *data, PixmapInfo *pi) {
     pi->map_image = NULL;
     pi->map_mask = NULL;
 
@@ -143,8 +115,8 @@ static void create_map_image(uint8 *data, PixmapInfo *pi)
 #if defined(HAVE_SDL)
         int i;
         SDL_Surface *fog;
-        uint32 g,*p;
-        uint8 *l;
+        guint32 g,*p;
+        guint8 *l;
 
 #if SDL_BYTEORDER == SDL_LIL_ENDIAN
         pi->map_image = SDL_CreateRGBSurfaceFrom(data, pi->map_width,
@@ -157,14 +129,14 @@ static void create_map_image(uint8 *data, PixmapInfo *pi)
         SDL_LockSurface(fog);
 
         for (i=0; i < pi->map_width * pi->map_height; i++) {
-            l = (uint8 *) (data + i*4);
+            l = (guint8 *) (data + i*4);
 #if 1
             g = MAX(*l, *(l+1));
             g = MAX(g, *(l+2));
 #else
             g = ( *l +  *(l+1) + *(l+2)) / 3;
 #endif
-            p = (uint32*) fog->pixels + i;
+            p = (guint32*) fog->pixels + i;
             *p = g | (g << 8) | (g << 16) | (*(l + 3) << 24);
         }
 
@@ -187,28 +159,28 @@ static void create_map_image(uint8 *data, PixmapInfo *pi)
          * just the bytes for it to go on the screen are reversed.
          */
         for (i=0; i < pi->map_width * pi->map_height; i++) {
-            l = (uint8 *) (data + i*4);
+            l = (guint8 *) (data + i*4);
 #if 1
             g = MAX(*l, *(l+1));
             g = MAX(g, *(l+2));
 #else
             g = ( *l +  *(l+1) + *(l+2)) / 3;
 #endif
-            p = (uint32*) fog->pixels + i;
+            p = (guint32*) fog->pixels + i;
             *p = (g << 8) | (g << 16) | (g << 24) | *(l + 3);
         }
 
         for (i=0; i < pi->map_width * pi->map_height; i+= 4) {
-            uint32 *tmp;
+            guint32 *tmp;
 
             /*
              * The pointer arithemtic below looks suspicious, but it is a patch
              * that is submitted, so just putting it in as submitted.  MSW
              * 2004-05-11
              */
-            p = (uint32*) (fog->pixels + i);
+            p = (guint32*) (fog->pixels + i);
             g = ( ((*p >> 24) & 0xff)  + ((*p >> 16) & 0xff) + ((*p >> 8) & 0xff)) / 3;
-            tmp = (uint32*) fog->pixels + i;
+            tmp = (guint32*) fog->pixels + i;
             *tmp = (g << 24) | (g << 16) | (g << 8) | (*p & 0xff);
         }
 
@@ -221,12 +193,8 @@ static void create_map_image(uint8 *data, PixmapInfo *pi)
 #ifdef HAVE_OPENGL
         create_opengl_map_image(data, pi);
 #endif
-    }
-
-    else if (use_config[CONFIG_DISPLAYMODE] == CFG_DM_PIXMAP) {
-        rgba_to_gdkpixmap(window_root->window, data, pi->map_width, pi->map_height,
-                          (GdkPixmap**)&pi->map_image, (GdkBitmap**)&pi->map_mask,
-                          gtk_widget_get_colormap(window_root));
+    } else if (use_config[CONFIG_DISPLAYMODE] == CFG_DM_PIXMAP) {
+        pi->map_image = rgba_to_cairo_surface(data, pi->map_width, pi->map_height);
     }
 }
 
@@ -244,7 +212,7 @@ static void free_pixmap(PixmapInfo *pi)
         g_object_unref(pi->icon_mask);
     }
     if (pi->map_mask) {
-        gdk_pixmap_unref(pi->map_mask);
+        g_object_unref(pi->map_mask);
     }
     if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_SDL) {
 #ifdef HAVE_SDL
@@ -272,7 +240,7 @@ static void free_pixmap(PixmapInfo *pi)
 #endif
     } else if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_PIXMAP) {
         if (pi->map_image) {
-            gdk_pixmap_unref(pi->map_image);
+            cairo_surface_destroy(pi->map_image);
         }
     }
 }
@@ -290,10 +258,9 @@ static void free_pixmap(PixmapInfo *pi)
  *
  * @return 1 on failure.
  */
-int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *rgba_data, int width, int height)
-{
+int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num,
+        guint8 *rgba_data, int width, int height) {
     int nx, ny, iscale, factor;
-    uint8 *png_tmp;
     PixmapInfo  *pi;
 
     if (pixmap_num <= 0 || pixmap_num >= MAXPIXMAPNUM) {
@@ -358,15 +325,15 @@ int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *r
     if (iscale != 100) {
         nx=width;
         ny=height;
-        png_tmp = rescale_rgba_data(rgba_data, &nx, &ny, iscale);
+        guint8 *png_tmp = rescale_rgba_data(rgba_data, &nx, &ny, iscale);
         pi->icon_width = nx;
         pi->icon_height = ny;
-        create_icon_image(png_tmp, pi, pixmap_num);
+        create_icon_image(png_tmp, pi);
         free(png_tmp);
     } else {
         pi->icon_width = width;
         pi->icon_height = height;
-        create_icon_image(rgba_data, pi, pixmap_num);
+        create_icon_image(rgba_data, pi);
     }
 
     /*
@@ -374,6 +341,8 @@ int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *r
      * more intelligent, but this should not be called too often, and this
      * keeps the code simpler.
      */
+    guint8 *png_tmp;
+
     if (use_config[CONFIG_MAPSCALE] != 100) {
         nx=width;
         ny=height;
@@ -397,7 +366,7 @@ int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *r
          * If using SDL mode, a copy of the rgba data needs to be stored away.
          */
         if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_SDL) {
-            png_tmp = malloc(width * height * BPP);
+            png_tmp = g_malloc(width * height * BPP);
             memcpy(png_tmp, rgba_data, width * height * BPP);
         } else {
             png_tmp = rgba_data;
@@ -431,7 +400,7 @@ int create_and_rescale_image_from_data(Cache_Entry *ce, int pixmap_num, uint8 *r
  * @param face
  * @param smooth_face
  */
-void addsmooth(uint16 face, uint16 smooth_face)
+void addsmooth(guint16 face, guint16 smooth_face)
 {
     pixmaps[face]->smooth_face = smooth_face;
 }
@@ -476,9 +445,7 @@ void reset_image_data(void)
     }
 }
 
-static GtkWidget     *pbar=NULL;
-static GtkWidget     *pbar_window=NULL;
-static GtkAdjustment *padj=NULL;
+static GtkWidget *pbar, *pbar_window;
 
 /**
  * Draws a status bar showing where we our in terms of downloading all the
@@ -491,43 +458,28 @@ static GtkAdjustment *padj=NULL;
  * @param end
  * @param total The total number of images.
  */
-void image_update_download_status(int start, int end, int total)
-{
+void image_update_download_status(int start, int end, int total) {
     int x, y, wx, wy, w, h;
 
     if (start == 1) {
-        padj = (GtkAdjustment*) gtk_adjustment_new (0, 1, total, 0, 0, 0);
-
-        pbar = gtk_progress_bar_new_with_adjustment(padj);
-        gtk_progress_set_format_string(GTK_PROGRESS(pbar), "Downloading image %v of %u (%p%% complete)");
-        gtk_progress_bar_set_bar_style(GTK_PROGRESS_BAR(pbar), GTK_PROGRESS_CONTINUOUS);
-        gtk_progress_set_show_text(GTK_PROGRESS(pbar), TRUE);
+        pbar = gtk_progress_bar_new();
         get_window_coord(window_root, &x,&y, &wx,&wy,&w,&h);
 
         pbar_window = gtk_window_new(GTK_WINDOW_POPUP);
-        gtk_window_set_policy(GTK_WINDOW(pbar_window), TRUE, TRUE, FALSE);
         gtk_window_set_transient_for(GTK_WINDOW(pbar_window), GTK_WINDOW (window_root));
-        /*
-         * We more or less want this window centered on the main crossfire
-         * window, and not necessarily centered on the screen or in the upper
-         * left corner.
-         */
-        gtk_widget_set_uposition(pbar_window, (wx + w)/2, (wy + h) / 2);
 
         gtk_container_add(GTK_CONTAINER(pbar_window), pbar);
         gtk_widget_show(pbar);
         gtk_widget_show(pbar_window);
-    }
-    if (start == total) {
+    } else if (start == total) {
         gtk_widget_destroy(pbar_window);
         pbar = NULL;
         pbar_window = NULL;
-        padj = NULL;
         return;
     }
 
-    gtk_progress_set_value(GTK_PROGRESS(pbar), start);
-    while ( gtk_events_pending() ) {
+    gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(pbar), (float)start / end);
+    while (gtk_events_pending()) {
         gtk_main_iteration();
     }
 }
@@ -538,7 +490,7 @@ void image_update_download_status(int start, int end, int total)
  * @param w
  * @param h
  */
-void get_map_image_size(int face, uint8 *w, uint8 *h)
+void get_map_image_size(int face, guint8 *w, guint8 *h)
 {
     /* We want to calculate the number of spaces this image
      * uses it.  By adding the image size but substracting one,
@@ -578,14 +530,12 @@ void init_image_cache_data(void)
 #include "../../pixmaps/question.xpm"
 
 
-    LOG(LOG_INFO,"gtk-v2::init_image_cache_data","Init Image Cache");
+    LOG(LOG_DEBUG, "gtk-v2::init_image_cache_data", "Init Image Cache");
 
     style = gtk_widget_get_style(window_root);
-    pixmaps[0] = malloc(sizeof(PixmapInfo));
-    pixmaps[0]->icon_image = gdk_pixmap_create_from_xpm_d(window_root->window,
-                             (GdkBitmap**)&pixmaps[0]->icon_mask,
-                             &style->bg[GTK_STATE_NORMAL],
-                             (gchar **)question_xpm);
+    pixmaps[0] = g_new(PixmapInfo, 1);
+    pixmaps[0]->icon_image =
+        gdk_pixbuf_new_from_xpm_data((const gchar **)question_xpm);
 #ifdef HAVE_SDL
     if (use_config[CONFIG_DISPLAYMODE]==CFG_DM_SDL) {
         /*
