@@ -12,21 +12,35 @@
  */
 
 /**
- * @file gtk-v2/src/info.c
- * This covers drawing text to the info window.
+ * @file
+ * Text-drawing functions for the message window
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "client.h"
 
 #include <gtk/gtk.h>
 
-#include "client.h"
 #include "image.h"
 #include "main.h"
 #include "gtk2proto.h"
 
+/** Color names set by the user in the gtkrc file. */
+static const char *const usercolorname[NUM_COLORS] = {
+    "black",                /* 0  */
+    "white",                /* 1  */
+    "darkblue",             /* 2  */
+    "red",                  /* 3  */
+    "orange",               /* 4  */
+    "lightblue",            /* 5  */
+    "darkorange",           /* 6  */
+    "green",                /* 7  */
+    "darkgreen",            /* 8  *//* Used for window background color */
+    "grey",                 /* 9  */
+    "brown",                /* 10 */
+    "yellow",               /* 11 */
+    "tan"                   /* 12 */
+};
+
 /**
  * A mapping of font numbers to style based on the rcfile content.
  */
@@ -696,7 +710,7 @@ static void add_to_textbuf(Info_Pane *pane, const char *message,
      */
     if (color) {
         for (color_num = 0; color_num < NUM_COLORS; color_num++)
-            if (!strcasecmp(usercolorname[color_num], color)) {
+            if (!g_ascii_strcasecmp(usercolorname[color_num], color)) {
                 break;
             }
         if (color_num < NUM_COLORS) {
@@ -747,7 +761,8 @@ static void add_to_textbuf(Info_Pane *pane, const char *message,
      * so check here on what to do.
      */
     if (pane->adjustment &&
-            (pane->adjustment->value + rect.height) >= pane->adjustment->upper) {
+        (gtk_adjustment_get_value(pane->adjustment) + rect.height) >=
+            gtk_adjustment_get_upper(pane->adjustment)) {
         scroll_to_end = 1;
     }
 
@@ -791,7 +806,7 @@ void add_marked_text_to_pane(Info_Pane *pane, const char *message, int type, int
                              *   color (unless no style set!)
                              */
 
-    current = strdup(message);
+    current = g_strdup(message);
     original = current;         /* Just so we know what to free */
 
     /*
@@ -1284,49 +1299,6 @@ void menu_clear(void)
     }
 }
 
-/**
- * A stub function that does nothing.  These are callbacks used by the common
- * code, but they are not implemented in GTK, either because it makes no sense
- * (set_scroll for example), or because it may not be technically possible to
- * do so if we limit ourselves to proper GTK2 code (Eg, don't mess with the
- * internals of X or platform specific issues)
- *
- * @param s
- */
-void set_scroll(const char *s)
-{
-}
-
-/**
- * A stub function that does nothing.  These are callbacks used by the common
- * code, but they are not implemented in GTK, either because it makes no sense
- * (set_scroll for example), or because it may not be technically possible to
- * do so if we limit ourselves to proper GTK2 code (Eg, don't mess with the
- * internals of X or platform specific issues)
- *
- * @param s
- */
-void set_autorepeat(const char *s)
-{
-}
-
-/**
- * This is used by the common help system to determine when to wrap.  Should be
- * able to get width of window, and divide by character width - however, still
- * not perfect if we are using a variable width font.  Actually, GTK can do
- * word wrapping for us, so maybe the real fix is to have it to the word
- * wrapping and just run a sufficiently large value.
- * @return The width of the info window in characters.
- */
-int get_info_width(void)
-{
-    /**
-     * @todo Configure automatic line wrap in message panels and get rid of
-     * the hardcoded 40-character wrap.
-     */
-    return 40;
-}
-
 /**
  * Initialize the message control panel by populating it with descriptions of
  * each message type along with checkboxes that are used to configure the
@@ -1527,8 +1499,7 @@ void save_msgctrl_configuration(void)
 
     read_msgctrl_configuration();       /* Apply the displayed settings 1st */
 
-    snprintf(pathbuf, sizeof(pathbuf), "%s/.crossfire/msgs", getenv("HOME"));
-    CONVERT_FILESPEC_TO_OS_FORMAT(pathbuf);
+    snprintf(pathbuf, sizeof(pathbuf), "%s/msgs", config_dir);
 
     if (make_path_to_file(pathbuf) == -1) {
         LOG(LOG_WARNING,
@@ -1601,8 +1572,7 @@ void load_msgctrl_configuration(void)
     buffer_parameter_t timerbuf;        /* Holding area for savefile values */
     guint cvalid, tvalid, mvalid;       /* Counts the valid entries found   */
 
-    snprintf(pathbuf, sizeof(pathbuf), "%s/.crossfire/msgs", getenv("HOME"));
-    CONVERT_FILESPEC_TO_OS_FORMAT(pathbuf);
+    snprintf(pathbuf, sizeof(pathbuf), "%s/msgs", config_dir);
 
     if ((fptr = fopen(pathbuf, "r")) == NULL) {
         snprintf(textbuf, sizeof(textbuf),
