@@ -17,17 +17,12 @@
  * and handling keypresses and looking up the keys.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "client.h"
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
-#include <stdlib.h>
-#include <sys/stat.h>
 
 #ifndef WIN32
-#include <unistd.h>
 #include <gdk/gdkx.h>
 #else
 #include <gdk/gdkwin32.h>
@@ -35,8 +30,6 @@
 typedef int KeyCode;                    /**< Undefined type */
 #endif
 
-#include "client-types.h"
-#include "client.h"
 #include "main.h"
 #include "proto.h"
 #include "def-keys.h"
@@ -105,9 +98,9 @@ static int cur_history_position = 0, scroll_history_position = 0;
  * A keybinding hash record structure.
  */
 struct keybind {
-    uint8       flags;                  /**< KEYF_* flags set for the record.*/
-    sint8       direction;              /**< -1 non-direction key, else >= 0.*/
-    uint32      keysym;                 /**< Key this binding record is for. */
+    guint8       flags;                  /**< KEYF_* flags set for the record.*/
+    gint8       direction;              /**< -1 non-direction key, else >= 0.*/
+    guint32      keysym;                 /**< Key this binding record is for. */
     char        *command;               /**< Command string bound to a key. */
     struct keybind *next;
 };
@@ -124,7 +117,7 @@ struct keybind {
  *
  ***********************************************************************/
 
-static uint32 firekeysym[2], runkeysym[2], commandkeysym, *bind_keysym,
+static guint32 firekeysym[2], runkeysym[2], commandkeysym, *bind_keysym,
        prevkeysym, nextkeysym, completekeysym, altkeysym[2], metakeysym[2],
        cancelkeysym;
 
@@ -196,7 +189,7 @@ static struct keybind *keys_global[KEYHASH], *keys_char[KEYHASH];
  * @param scope Determines which scope to search for the binding.
  *              0 meaning char scope, non zero meaning global scope.
  */
-static struct keybind *keybind_find(uint32 keysym, unsigned int flags,
+static struct keybind *keybind_find(guint32 keysym, unsigned int flags,
                                     int scope) {
     struct keybind *kb;
     kb = scope ? keys_global[keysym % KEYHASH] : keys_char[keysym % KEYHASH];
@@ -225,7 +218,7 @@ static struct keybind *keybind_find(uint32 keysym, unsigned int flags,
  * @param flags State that the keyboard is in.
  * @param command A command to bind to the key specified in keysym.
  */
-static int keybind_insert(uint32 keysym, unsigned int flags,
+static int keybind_insert(guint32 keysym, unsigned int flags,
                           const char *command) {
     struct keybind **next_ptr, *kb;
     int slot;
@@ -240,7 +233,7 @@ static int keybind_insert(uint32 keysym, unsigned int flags,
          * Also, if the new binding has the ANY flag, remove all matching
          * previous bindings and keep this one.
          */
-        LOG(LOG_WARNING, "gtk-v2::keybind_insert",
+        LOG(LOG_DEBUG, "gtk-v2::keybind_insert",
             "Overwriting previous binding for key %s with command %s ",
             gdk_keyval_name(keysym), kb->command);
         keybind_remove(kb);
@@ -261,7 +254,7 @@ static int keybind_insert(uint32 keysym, unsigned int flags,
 
     (*next_ptr)->keysym = keysym;
     (*next_ptr)->flags = flags;
-    (*next_ptr)->command = strdup_local(command);
+    (*next_ptr)->command = g_strdup(command);
 
     /*
      * Try to find out if the command is a direction command.  If so, keep
@@ -315,7 +308,7 @@ static void keybind_free(struct keybind **entry) {
  */
 static void parse_keybind_line(char *buf, int line, unsigned int scope_flag) {
     char *cp, *cpnext;
-    uint32 keysym, low_keysym;
+    guint32 keysym, low_keysym;
     int flags;
 
     /*
@@ -494,13 +487,9 @@ static void parse_keybind_line(char *buf, int line, unsigned int scope_flag) {
  * Load pre-compiled built-in default keybindings.
  */
 static void init_default_keybindings() {
-    char *nextline;
-    int i;
-
     LOG(LOG_DEBUG, "init_default_keybindings", "Loading default keybindings");
-
-    for (i = 0; i < sizeof(def_keys) / sizeof(char *); i++) {
-        nextline = strdup(def_keys[i]);
+    for (size_t i = 0; i < sizeof(def_keys) / sizeof(char *); i++) {
+        char *nextline = g_strdup(def_keys[i]);
         parse_keybind_line(nextline, i, KEYF_R_GLOBAL);
         free(nextline);
     }
@@ -519,7 +508,6 @@ static int parse_keys_file(char *filename, unsigned int scope_flag) {
     char buf[BIG_BUF];
     int line = 0;
 
-    CONVERT_FILESPEC_TO_OS_FORMAT(filename);
     fp = fopen(filename, "r");
     if (fp == NULL) {
         return -1;
@@ -593,7 +581,7 @@ void keybindings_init(const char *character_name) {
         cpl.name = NULL;
     }
     if (character_name) {
-        cpl.name = strdup(character_name);
+        cpl.name = g_strdup(character_name);
     }
 
     /*
@@ -611,13 +599,13 @@ void keybindings_init(const char *character_name) {
     init_default_keybindings();
 
     /* Try to load global keybindings. */
-    snprintf(buf, sizeof(buf), "%s/.crossfire/keys", getenv("HOME"));
+    snprintf(buf, sizeof(buf), "%s/keys", config_dir);
     parse_keys_file(buf, KEYF_R_GLOBAL);
 
     /* Try to load the character-specific keybindings. */
     if (cpl.name) {
-        snprintf(buf, sizeof(buf), "%s/.crossfire/%s.%s.keys",
-                getenv("HOME"), csocket.servername, cpl.name);
+        snprintf(buf, sizeof(buf), "%s/%s.%s.keys", config_dir,
+                csocket.servername, cpl.name);
         parse_keys_file(buf, KEYF_R_CHAR);
     }
 }
@@ -784,7 +772,7 @@ void keys_init(GtkWidget *window_root) {
  *
  * @param ks
  */
-static void parse_key_release(uint32 keysym) {
+static void parse_key_release(guint32 keysym) {
 
     /*
      * Only send stop firing/running commands if we are in actual play mode.
@@ -794,14 +782,14 @@ static void parse_key_release(uint32 keysym) {
     if (keysym == firekeysym[0] || keysym == firekeysym[1]) {
         cpl.fire_on = 0;
         clear_fire();
-        gtk_label_set(GTK_LABEL(fire_label), "    ");
+        gtk_label_set_text(GTK_LABEL(fire_label), "    ");
     } else if (keysym == runkeysym[0] || keysym == runkeysym[1]) {
         cpl.run_on = 0;
         if (use_config[CONFIG_ECHO])
             draw_ext_info(NDI_BLACK, MSG_TYPE_CLIENT, MSG_TYPE_CLIENT_NOTICE,
                           "stop run");
         clear_run();
-        gtk_label_set(GTK_LABEL(run_label), "   ");
+        gtk_label_set_text(GTK_LABEL(run_label), "   ");
     } else if (keysym == altkeysym[0] || keysym == altkeysym[1]) {
         cpl.alt_on = 0;
     } else if (keysym == metakeysym[0] || keysym == metakeysym[1]) {
@@ -823,7 +811,7 @@ static void parse_key_release(uint32 keysym) {
  * @param key
  * @param keysym
  */
-static void parse_key(char key, uint32 keysym) {
+static void parse_key(char key, guint32 keysym) {
     struct keybind *kb;
     int present_flags = 0;
     char buf[MAX_BUF], tmpbuf[MAX_BUF];
@@ -848,12 +836,12 @@ static void parse_key(char key, uint32 keysym) {
     }
     if (keysym == firekeysym[0] || keysym == firekeysym[1]) {
         cpl.fire_on = 1;
-        gtk_label_set(GTK_LABEL(fire_label), "Fire");
+        gtk_label_set_text(GTK_LABEL(fire_label), "Fire");
         return;
     }
     if (keysym == runkeysym[0] || keysym == runkeysym[1]) {
         cpl.run_on = 1;
-        gtk_label_set(GTK_LABEL(run_label), "Run");
+        gtk_label_set_text(GTK_LABEL(run_label), "Run");
         return;
     }
 
@@ -1274,9 +1262,8 @@ static void save_keys(void) {
 
     /* If we are logged in open file to save character specific bindings */
     if (cpl.name) {
-        snprintf(buf, sizeof(buf), "%s/.crossfire/%s.%s.keys",
-                 getenv("HOME"), csocket.servername, cpl.name);
-        CONVERT_FILESPEC_TO_OS_FORMAT(buf);
+        snprintf(buf, sizeof(buf), "%s/%s.%s.keys", config_dir,
+                csocket.servername, cpl.name);
         LOG(LOG_INFO, "gtk-v2::save_keys",
             "Saving character specific keybindings to %s", buf);
 
@@ -1298,8 +1285,7 @@ static void save_keys(void) {
     }
 
     /* Open file to save global user bindings */
-    snprintf(buf, sizeof(buf), "%s/.crossfire/keys", getenv("HOME"));
-    CONVERT_FILESPEC_TO_OS_FORMAT(buf);
+    snprintf(buf, sizeof(buf), "%s/keys", config_dir);
     LOG(LOG_INFO, "gtk-v2::save_keys",
         "Saving global user's keybindings to %s", buf);
 
@@ -1364,7 +1350,7 @@ static void save_keys(void) {
  *
  * @param keysym
  */
-static void configure_keys(uint32 keysym) {
+static void configure_keys(guint32 keysym) {
     char buf[MAX_BUF];
     struct keybind *kb;
 
@@ -1528,7 +1514,7 @@ void focusoutfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
     if (cpl.fire_on == 1) {
         cpl.fire_on = 0;
         clear_fire();
-        gtk_label_set(GTK_LABEL(fire_label), "    ");
+        gtk_label_set_text(GTK_LABEL(fire_label), "    ");
     }
     if (cpl.run_on == 1) {
         cpl.run_on = 0;
@@ -1536,7 +1522,7 @@ void focusoutfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
             draw_ext_info(NDI_BLACK, MSG_TYPE_CLIENT, MSG_TYPE_CLIENT_NOTICE,
                           "stop run");
         clear_run();
-        gtk_label_set(GTK_LABEL(run_label), "   ");
+        gtk_label_set_text(GTK_LABEL(run_label), "   ");
     }
     if (cpl.alt_on == 1) {
         cpl.alt_on = 0;
@@ -1554,7 +1540,7 @@ void focusoutfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
  * @param window
  */
 void keyrelfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
-    if (event->keyval > 0 && !GTK_WIDGET_HAS_FOCUS(entry_commands)) {
+    if (event->keyval > 0 && !gtk_widget_has_focus(entry_commands)) {
         parse_key_release(event->keyval);
     }
     g_signal_stop_emission_by_name(GTK_OBJECT(window), "key_release_event");
@@ -1579,13 +1565,8 @@ void keyfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
              * menubar)
              */
 
-            close_server_connection();
+            client_disconnect();
 
-            if (csocket_fd) {
-                gdk_input_remove(csocket_fd);
-                csocket_fd = 0;
-                gtk_main_quit();
-            }
             g_signal_stop_emission_by_name(
                 GTK_OBJECT(window), "key_press_event");
             return;
@@ -1598,7 +1579,7 @@ void keyfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
                 GTK_OBJECT(window), "key_press_event");
             return;
         } else if (cpl.input_state == Reply_Many) {
-            if (GTK_WIDGET_HAS_FOCUS(entry_commands)) {
+            if (gtk_widget_has_focus(entry_commands)) {
                 gtk_widget_event(GTK_WIDGET(entry_commands), (GdkEvent *)event);
             } else {
                 gtk_widget_grab_focus(GTK_WIDGET(entry_commands));
@@ -1613,7 +1594,7 @@ void keyfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
      * handling these key values.
      */
     if (event->keyval > 0) {
-        if (GTK_WIDGET_HAS_FOCUS(entry_commands)) {
+        if (gtk_widget_has_focus(entry_commands)) {
             if (event->keyval == completekeysym) {
                 gtk_complete_command();
             }
@@ -1637,7 +1618,7 @@ void keyfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
                         if (cpl.run_on) {
                             if (!(event->state & GDK_CONTROL_MASK)) {
                                 /* printf("Run is on while ctrl is not\n"); */
-                                gtk_label_set(GTK_LABEL(run_label), "   ");
+                                gtk_label_set_text(GTK_LABEL(run_label), "   ");
                                 cpl.run_on = 0;
                                 stop_run();
                             }
@@ -1645,18 +1626,12 @@ void keyfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
                         if (cpl.fire_on) {
                             if (!(event->state & GDK_SHIFT_MASK)) {
                                 /* printf("Fire is on while shift is not\n");*/
-                                gtk_label_set(GTK_LABEL(fire_label), "   ");
+                                gtk_label_set_text(GTK_LABEL(fire_label), "   ");
                                 cpl.fire_on = 0;
                                 stop_fire();
                             }
                         }
 
-                        if ((event->state & GDK_CONTROL_MASK)
-                                && (event->state & GDK_SHIFT_MASK)
-                                && (event->keyval == GDK_i || event->keyval == GDK_I)) {
-                            reset_map();
-                        }
-
                         parse_key(event->string[0], event->keyval);
                     }
                     break;
@@ -1680,7 +1655,7 @@ void keyfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
                          * window.  So we have to pass the event to it
                          * explicitly.
                          */
-                        if (GTK_WIDGET_HAS_FOCUS(entry_commands) == 0)
+                        if (gtk_widget_has_focus(entry_commands) == 0)
                             gtk_widget_event(
                                 GTK_WIDGET(entry_commands), (GdkEvent *)event);
                     }
@@ -1705,43 +1680,6 @@ void keyfunc(GtkWidget *widget, GdkEventKey *event, GtkWidget *window) {
         GTK_OBJECT(window), "key_press_event");
 }
 
-/**
- * Output the current list of keybindings to the message pane.
- *
- * @param keylist
- */
-void draw_keybindings(GtkWidget *keylist) {
-    int i, j, count = 1;
-    struct keybind *kb;
-    char buff[MAX_BUF];
-    char buffer[5][MAX_BUF];
-    char *buffers[5];
-
-    gtk_clist_clear(GTK_CLIST(keylist));
-    for (i = 0; i < KEYHASH; i++) {
-        for (j = 0; j < 2; j++) {
-            for (kb = (j == 0) ? keys_global[i] : keys_char[i]; kb != NULL; kb = kb->next) {
-                get_key_modchars(kb, 0, buff);
-
-                if (kb->keysym != NoSymbol) {
-                    snprintf(buffer[0], sizeof(buffer[0]), "%i", count);
-                    snprintf(buffer[1], sizeof(buffer[1]), "%s", gdk_keyval_name(kb->keysym));
-                    snprintf(buffer[2], sizeof(buffer[2]), "%i", i);
-                    snprintf(buffer[3], sizeof(buffer[3]), "%s", buff);
-                    snprintf(buffer[4], sizeof(buffer[4]), "%s", kb->command);
-                    buffers[0] = buffer[0];
-                    buffers[1] = buffer[1];
-                    buffers[2] = buffer[2];
-                    buffers[3] = buffer[3];
-                    buffers[4] = buffer[4];
-                    gtk_clist_append(GTK_CLIST(keylist), buffers);
-                }
-                count++;
-            }
-        }
-    }
-}
-
 /**
  *
  */
@@ -1785,7 +1723,7 @@ void gtk_command_history(int direction) {
              * now.
              */
             gtk_entry_set_text(GTK_ENTRY(entry_commands), "");
-            gtk_entry_set_position(GTK_ENTRY(entry_commands), 0);
+            gtk_editable_set_position(GTK_EDITABLE(entry_commands), 0);
             scroll_history_position = cur_history_position;
             return;
         }
@@ -2269,7 +2207,7 @@ void on_keybinding_button_remove_clicked(GtkButton *button,
  * @param flags
  * @param command
  */
-static void keybinding_get_data(uint32 *keysym, uint8 *flags,
+static void keybinding_get_data(guint32 *keysym, guint8 *flags,
                                 const char **command) {
     static char bind_buf[MAX_BUF];
     const char *ed;
@@ -2337,14 +2275,14 @@ static void keybinding_get_data(uint32 *keysym, uint8 *flags,
  * @param user_data
  */
 void on_keybinding_button_bind_clicked(GtkButton *button, gpointer user_data) {
-    uint32 keysym;
-    uint8 flags;
+    guint32 keysym;
+    guint8 flags;
     const char *command;
     struct keybind *kb;
 
     keybinding_get_data(&keysym, &flags, &command);
 
-    /* keybind_insert will do a strdup of command for us */
+    /* keybind_insert will do a g_strdup of command for us */
     kb = keybind_find(keysym, flags, (flags & KEYF_R_GLOBAL));
     if (kb && (!keybind_overwrite_confirm(kb))) {
         return;
@@ -2375,8 +2313,8 @@ void on_keybinding_button_update_clicked(GtkButton *button,
     GtkTreeIter iter;
     struct keybind *kb;
     GtkTreeModel *model;
-    uint32 keysym;
-    uint8 flags;
+    guint32 keysym;
+    guint8 flags;
     const char *buf;
     int res;
 
