@@ -21,18 +21,20 @@ extern GdkColor root_color[NUM_COLORS];
 extern GtkWidget *window_root, *spinbutton_count;
 extern GtkBuilder *dialog_xml, *window_xml;
 
+extern GtkWidget *magic_map;
+extern GtkWidget *map_notebook;
+
 #define DEFAULT_IMAGE_SIZE      32
 extern int map_image_size, map_image_half_size, image_size;
 
-#define XML_PATH_DEFAULT CF_DATADIR "/ui/"
-#define WINDOW_XML_FILENAME "gtk-v1.ui"
-#define DIALOG_XML_FILENAME "dialogs.ui"
-extern char window_xml_file[];
+#define DEFAULT_UI CF_DATADIR "/ui/gtk-v2.ui"
+#define DIALOG_FILENAME CF_DATADIR "/ui/dialogs.ui"
+
+/** Path to the current UI file. */
+char window_xml_file[MAX_BUF];
 
 #define MAGIC_MAP_PAGE  1 /**< Notebook page of the magic map */
 
-extern gint csocket_fd;
-
 extern char account_password[256];
 /* gtk2proto.h depends on this - so may as well just include it here */
 #include "info.h"
