@@ -12,24 +12,17 @@
  */
 
 /**
- * @file gtk-v2/src/opengl.c
+ * @file
  * Implements an opengl version of the map renderer.  I've tried to keep this
  * platform generic, but there are just some things that must be tied to the
  * window system is is using, namely, window creation and flipping the data
  * buffers.  For that, on X, we use to use glx - MSW 2005-03-12
- *
- * NOTE: Using dmalloc with opengl causes problems - it gets an invalid
- * allocation - I haven't dug through it, but my guess is that some internal
- * opengl/glx routine is doing something like a malloc(0) which dmalloc
- * catches.
  */
 
-#include <config.h>
+#include "client.h"
 
 #ifdef HAVE_OPENGL
 
-#include <client-types.h>
-
 #include <errno.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
@@ -41,11 +34,9 @@
 #include <gdk/gdkwin32.h>
 #endif
 
-#include <client.h>
-#include "main.h"
 #include "image.h"
+#include "main.h"
 #include "mapdata.h"
-
 #include "gtk2proto.h"
 
 /* Start of Open GL includes */
@@ -249,7 +240,7 @@ void init_opengl(GtkWidget* drawingarea)
  * logic for final row/column).  That is +1 value.  but the last row also has
  * the right/bottom side vertices, and that is where the other +1 comes from
  */
-static uint16 map_darkness[(MAP_MAX_SIZE+2)*2][(MAP_MAX_SIZE+2)*2];
+static guint16 map_darkness[(MAP_MAX_SIZE+2)*2][(MAP_MAX_SIZE+2)*2];
 
 /*
  * This is darkness to use if we have no darkness information.  0 makes sense
@@ -282,11 +273,11 @@ static void opengl_light_space(int x, int y, int mx, int my)
 {
     if (use_config[CONFIG_DARKNESS] == CFG_LT_TILE) {
         /* If we don't have darkness, or it isn't dark, don't do anything */
-        if (!the_map.cells[mx][my].have_darkness || the_map.cells[mx][my].darkness==0) {
+        if (!mapdata_cell(mx, my)->have_darkness || mapdata_cell(mx, my)->darkness==0) {
             return;
         }
 
-        glColor4ub(0, 0, 0,  the_map.cells[mx][my].darkness);
+        glColor4ub(0, 0, 0,  mapdata_cell(mx, my)->darkness);
         glBegin(GL_QUADS);
         glVertex3i(x * map_image_size, y * map_image_size, 0);
         glVertex3i((x+1) * map_image_size, y * map_image_size, 0);
@@ -411,16 +402,16 @@ static void drawsmooth_opengl (int x, int y, int mx, int my, int layer)
         emx=mx+dx[i];
         emy=my+dy[i];
 
-        if ( (emx<0) || (emy<0) || (emx >= the_map.x) || (emy >= the_map.y)) {
+        if (!mapdata_contains(emx, emy)) {
             slevels[i]=0;
             sfaces[i]=0; /*black picture*/
-        } else if (the_map.cells[emx][emy].smooth[layer]<=the_map.cells[mx][my].smooth[layer] ||
-                   the_map.cells[emx][emy].heads[layer].face == 0) {
+        } else if (mapdata_cell(emx, emy)->smooth[layer]<=mapdata_cell(mx, my)->smooth[layer] ||
+                   mapdata_cell(emx, emy)->heads[layer].face == 0) {
             slevels[i]=0;
             sfaces[i]=0; /*black picture*/
         } else {
-            slevels[i]=the_map.cells[emx][emy].smooth[layer];
-            sfaces[i]=pixmaps[the_map.cells[emx][emy].heads[layer].face]->smooth_face;
+            slevels[i]=mapdata_cell(emx, emy)->smooth[layer];
+            sfaces[i]=pixmaps[mapdata_cell(emx, emy)->heads[layer].face]->smooth_face;
             dosmooth++;
         }
     }
@@ -477,7 +468,7 @@ static void drawsmooth_opengl (int x, int y, int mx, int my, int layer)
             continue;    /*don't have the picture associated*/
         }
 
-        if (the_map.cells[mx][my].cleared) {
+        if (mapdata_cell(mx, my)->cleared) {
             glBindTexture(GL_TEXTURE_2D, pixmaps[smoothface]->fog_texture);
         } else {
             glBindTexture(GL_TEXTURE_2D, pixmaps[smoothface]->map_texture);
@@ -539,7 +530,7 @@ static void draw_smoothing(int layer)
             mx = x + pl_pos.x;
             my = y + pl_pos.y;
 
-            if (CAN_SMOOTH(the_map.cells[mx][my],layer)) {
+            if (mapdata_can_smooth(mx, my,layer)) {
                 drawsmooth_opengl(x, y, mx, my, layer);
             }
         }
@@ -561,16 +552,8 @@ static void draw_smoothing(int layer)
  *
  * @param redraw
  */
-void opengl_gen_map(int redraw)
-{
-    long elapsed1, elapsed2;
-    struct timeval tv1, tv2,tv3;
+void opengl_gen_map(int redraw) {
     int mx,my, layer,x,y, d1, d2, d3, num_dark, got_smooth, face, t1, t2;
-
-    if (time_map_redraw) {
-        gettimeofday(&tv1, NULL);
-    }
-
     glClear(GL_COLOR_BUFFER_BIT);
 
     /*
@@ -654,8 +637,8 @@ void opengl_gen_map(int redraw)
                          * But the results we use here, while perhaps not as
                          * nice, certainly look better than per tile lighting.
                          */
-                        if (the_map.cells[mx][my].have_darkness) {
-                            map_darkness[x*2 + 1][y*2 + 1] = the_map.cells[mx][my].darkness;
+                        if (mapdata_cell(mx, my)->have_darkness) {
+                            map_darkness[x*2 + 1][y*2 + 1] = mapdata_cell(mx, my)->darkness;
                         } else {
                             map_darkness[x*2 + 1][y*2 + 1] = DEFAULT_DARKNESS;
                         }
@@ -665,18 +648,18 @@ void opengl_gen_map(int redraw)
                         d3 = DEFAULT_DARKNESS;  /* square above */
                         num_dark=1; /* Number of adjoining spaces w/darkness */
 
-                        if (x>0 && the_map.cells[mx-1][my].have_darkness) {
-                            d1 = the_map.cells[mx-1][my].darkness;
+                        if (x>0 && mapdata_cell(mx-1, my)->have_darkness) {
+                            d1 = mapdata_cell(mx-1, my)->darkness;
                             num_dark++;
                         }
 
-                        if (x>0 && y>0 && the_map.cells[mx-1][my-1].have_darkness) {
-                            d2 = the_map.cells[mx-1][my-1].darkness;
+                        if (x>0 && y>0 && mapdata_cell(mx-1, my-1)->have_darkness) {
+                            d2 = mapdata_cell(mx-1, my-1)->darkness;
                             num_dark++;
                         }
 
-                        if (y>0 && the_map.cells[mx][my-1].have_darkness) {
-                            d3 = the_map.cells[mx][my-1].darkness;
+                        if (y>0 && mapdata_cell(mx, my-1)->have_darkness) {
+                            d3 = mapdata_cell(mx, my-1)->darkness;
                             num_dark++;
                         }
 #if 0
@@ -711,16 +694,16 @@ void opengl_gen_map(int redraw)
 #endif
                     }
 
-                    if (the_map.cells[mx][my].heads[layer].face) {
-                        if (pixmaps[the_map.cells[mx][my].heads[layer].face]->map_texture) {
+                    if (mapdata_cell(mx, my)->heads[layer].face) {
+                        if (pixmaps[mapdata_cell(mx, my)->heads[layer].face]->map_texture) {
                             int nx, ny;
 
                             /*
                              * nx, ny are the location of the top/left side of
                              * the image to draw.
                              */
-                            nx = (x+1) * map_image_size - pixmaps[the_map.cells[mx][my].heads[layer].face]->map_width;
-                            ny = (y+1) * map_image_size - pixmaps[the_map.cells[mx][my].heads[layer].face]->map_height;
+                            nx = (x+1) * map_image_size - pixmaps[mapdata_cell(mx, my)->heads[layer].face]->map_width;
+                            ny = (y+1) * map_image_size - pixmaps[mapdata_cell(mx, my)->heads[layer].face]->map_height;
                             /*
                              * If both nx and ny are outside visible area,
                              * don't need to do anything more
@@ -734,10 +717,10 @@ void opengl_gen_map(int redraw)
                              * of war logic.  I don't have good solution to
                              * that, other than to live with it.
                              */
-                            if (the_map.cells[mx][my].cleared) {
-                                glBindTexture(GL_TEXTURE_2D, pixmaps[the_map.cells[mx][my].heads[layer].face]->fog_texture);
+                            if (mapdata_cell(mx, my)->cleared) {
+                                glBindTexture(GL_TEXTURE_2D, pixmaps[mapdata_cell(mx, my)->heads[layer].face]->fog_texture);
                             } else {
-                                glBindTexture(GL_TEXTURE_2D, pixmaps[the_map.cells[mx][my].heads[layer].face]->map_texture);
+                                glBindTexture(GL_TEXTURE_2D, pixmaps[mapdata_cell(mx, my)->heads[layer].face]->map_texture);
                             }
 
                             glBegin(GL_QUADS);
@@ -756,8 +739,8 @@ void opengl_gen_map(int redraw)
 
                             glEnd();
                         }
-                        if (use_config[CONFIG_SMOOTH] && CAN_SMOOTH(the_map.cells[mx][my],layer) &&
-                                the_map.cells[mx][my].heads[layer].face !=0) {
+                        if (use_config[CONFIG_SMOOTH] && mapdata_can_smooth(mx, my, layer) &&
+                                mapdata_cell(mx, my)->heads[layer].face !=0) {
 
                             got_smooth=1;
                         }
@@ -785,7 +768,7 @@ void opengl_gen_map(int redraw)
                              * of war logic.  I don't have good solution to
                              * that, other than to live with it.
                              */
-                            if (the_map.cells[mx][my].cleared) {
+                            if (mapdata_cell(mx, my)->cleared) {
                                 glBindTexture(GL_TEXTURE_2D, pixmaps[face]->fog_texture);
                             } else {
                                 glBindTexture(GL_TEXTURE_2D, pixmaps[face]->map_texture);
@@ -827,29 +810,12 @@ void opengl_gen_map(int redraw)
         }
     }
 
-    if (time_map_redraw) {
-        gettimeofday(&tv2, NULL);
-    }
-
 #ifndef WIN32
     glXSwapBuffers(display, window);
 #else
     SwapBuffers(devicecontext);
 #endif
-
-    if (time_map_redraw) {
-        gettimeofday(&tv3, NULL);
-        elapsed1 = (tv2.tv_sec - tv1.tv_sec)*1000000 + (tv2.tv_usec - tv1.tv_usec);
-        elapsed2 = (tv3.tv_sec - tv2.tv_sec)*1000000 + (tv3.tv_usec - tv2.tv_usec);
-        /*
-         * I care about performance for 'long' updates, so put the check in to
-         * make these a little more noticable
-         */
-        if ((elapsed1 + elapsed2)>10000)
-            LOG(LOG_INFO,"gtk-v2::opengl_gen_map","gen took %7ld, flip took %7ld, total = %7ld",
-                elapsed1, elapsed2, elapsed1 + elapsed2);
-    }
-} /* opengl_gen_map function */
+}
 
 /**
  * Rather than put a bunch of opengl code in the image.c file, it instead calls
@@ -858,13 +824,13 @@ void opengl_gen_map(int redraw)
  * @param data
  * @param pi
  */
-void create_opengl_map_image(uint8 *data, PixmapInfo *pi)
+void create_opengl_map_image(guint8 *data, PixmapInfo *pi)
 {
-    static uint8 *newdata;
+    static guint8 *newdata;
     static int size=0;
     int nwidth, nheight, numshifts, i;
-    uint8 *data_to_use = data, *l;
-    uint32 g, *p;
+    guint8 *data_to_use = data, *l;
+    guint32 g, *p;
 
     /*
      * The width and height of textures has to be a power of 2.  so 32x32 and
@@ -898,7 +864,7 @@ void create_opengl_map_image(uint8 *data, PixmapInfo *pi)
      */
     if (pi->map_width != nwidth || pi->map_height != nheight) {
         int y;
-        uint8   *datastart;
+        guint8   *datastart;
 
         /*
          * Use a static buffer to hold image data, so we don't have to keep
@@ -906,7 +872,7 @@ void create_opengl_map_image(uint8 *data, PixmapInfo *pi)
          */
         if (nwidth * nheight * 4 > size) {
             size = nwidth * nheight * 4;
-            newdata = realloc(newdata, size);
+            newdata = g_realloc(newdata, size);
 
             if (newdata == NULL) {
                 LOG(LOG_ERROR, "create_opengl_map_image",
@@ -952,7 +918,7 @@ void create_opengl_map_image(uint8 *data, PixmapInfo *pi)
 
     if (pi->map_width * pi->map_height * 4 > size) {
         size = pi->map_width * pi->map_height * 4;
-        newdata = realloc(newdata, size);
+        newdata = g_realloc(newdata, size);
     }
 
     /* In this case, newdata does not contain a copy of the data - make one */
@@ -961,10 +927,10 @@ void create_opengl_map_image(uint8 *data, PixmapInfo *pi)
     }
 
     for (i=0; i < pi->map_width * pi->map_height; i++) {
-        l = (uint8 *) (newdata + i*4);
+        l = (guint8 *) (newdata + i*4);
         g = MAX(*l, *(l+1));
         g = MAX(g, *(l+2));
-        p = (uint32*) newdata + i;
+        p = (guint32*) newdata + i;
         *p = g | (g << 8) | (g << 16) | (*(l + 3) << 24);
     }
 
