@@ -12,30 +12,15 @@
  */
 
 /**
- * @file gtk-v2/src/png.c
+ * @file
  * Functions for manipulating graphics in the GTK-V2 client.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "client.h"
 
 #include <errno.h>
-#include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <png.h>
-#include <stdlib.h>
-#include <sys/stat.h>
-
-#ifndef WIN32
-#include <gdk/gdkx.h>
-#include <unistd.h>
-#else
-#include <gdk/gdkwin32.h>
-#endif
-
-#include "client-types.h"
-#include "client.h"
 
 /* Defines for PNG return values */
 /* These should be in a header file, but currently our calling functions
@@ -46,7 +31,7 @@
 #define PNGX_OUTOFMEM   2
 #define PNGX_DATA       3
 
-static uint8 *data_cp;
+static guint8 *data_cp;
 static int data_len, data_start;
 
 /**
@@ -61,49 +46,37 @@ static void user_read_data(png_structp png_ptr, png_bytep data, png_size_t lengt
     data_start += length;
 }
 
-/**
- *
- * @param *data
- * @param len
- * @param *width
- * @param *height
- */
-uint8 *png_to_data(uint8 *data, int len, uint32 *width, uint32 *height)
-{
-    uint8 *pixels=NULL;
-    static png_bytepp   rows=NULL;
-    static int rows_byte=0;
+guint8 *png_to_data(guint8 *data, int len, guint32 *width, guint32 *height) {
+    guint8 *pixels = NULL;
+    static png_bytepp rows = NULL;
+    static guint32 rows_byte = 0;
 
     png_structp png_ptr;
-    png_infop   info_ptr;
-    int bit_depth, color_type, interlace_type, y;
+    png_infop info_ptr;
+    int bit_depth, color_type, interlace_type;
 
-    data_len=len;
+    data_len = len;
     data_cp = data;
-    data_start=0;
-
-    png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING,
-                                     NULL, NULL, NULL);
+    data_start = 0;
 
+    png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
     if (!png_ptr) {
         return NULL;
     }
-    info_ptr = png_create_info_struct (png_ptr);
 
+    info_ptr = png_create_info_struct(png_ptr);
     if (!info_ptr) {
-        png_destroy_read_struct (&png_ptr, NULL, NULL);
+        png_destroy_read_struct(&png_ptr, NULL, NULL);
         return NULL;
     }
 
-
-    if (setjmp (png_jmpbuf(png_ptr))) {
-        png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
+    if (setjmp(png_jmpbuf(png_ptr))) {
+        png_destroy_read_struct(&png_ptr, &info_ptr, NULL);
         return NULL;
     }
 
-
     png_set_read_fn(png_ptr, NULL, user_read_data);
-    png_read_info (png_ptr, info_ptr);
+    png_read_info(png_ptr, info_ptr);
 
     /*
      * This seems to bug on at least one system (other than mine)
@@ -183,7 +156,7 @@ uint8 *png_to_data(uint8 *data, int len, uint32 *width, uint32 *height)
     *width = png_get_image_width(png_ptr, info_ptr);
     *height = png_get_image_height(png_ptr, info_ptr);
 
-    pixels = (uint8*)malloc(*width **height * 4);
+    pixels = (guint8*)g_malloc(*width **height * 4);
 
     if (!pixels) {
         png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
@@ -193,10 +166,10 @@ uint8 *png_to_data(uint8 *data, int len, uint32 *width, uint32 *height)
 
     /* the png library needs the rows, but we will just return the raw data */
     if (rows_byte == 0) {
-        rows = (png_bytepp)malloc(sizeof(png_byte *) **height);
+        rows = (png_bytepp)g_malloc(sizeof(png_byte *) **height);
         rows_byte = *height;
     } else if (*height > rows_byte) {
-        rows = (png_bytepp)realloc(rows, sizeof(png_byte *) **height);
+        rows = (png_bytepp)g_realloc(rows, sizeof(png_byte *) **height);
 
         if (rows == NULL) {
             LOG(LOG_ERROR, "png_to_data",
@@ -212,8 +185,8 @@ uint8 *png_to_data(uint8 *data, int len, uint32 *width, uint32 *height)
         return NULL;
     }
 
-    for (y=0; y<*height; y++) {
-        rows[y] = pixels + y **width * 4;
+    for (guint32 y = 0; y < *height; y++) {
+        rows[y] = pixels + y * *width * 4;
     }
 
     png_read_image(png_ptr, rows);
@@ -247,7 +220,7 @@ uint8 *png_to_data(uint8 *data, int len, uint32 *width, uint32 *height)
  * properly.
  *
  * This function returns a new pointer to the scaled image data.  This is
- * malloc'd data, so should be freed at some point to prevent leaks.  This
+ * g_malloc'd data, so should be freed at some point to prevent leaks.  This
  * function does not modify the data passed to it - the caller is responsible
  * for freeing it if it is no longer needed.
  *
@@ -259,10 +232,10 @@ uint8 *png_to_data(uint8 *data, int len, uint32 *width, uint32 *height)
  *              image - values larger than 100 will result in zoom, values less
  *              than 100 will result in a shrinkage.
  */
-uint8 *rescale_rgba_data(uint8 *data, int *width, int *height, int scale)
+guint8 *rescale_rgba_data(guint8 *data, int *width, int *height, int scale)
 {
     static int xrow[BPP * MAX_IMAGE_WIDTH], yrow[BPP*MAX_IMAGE_HEIGHT];
-    static uint8 *nrows[MAX_IMAGE_HEIGHT];
+    static guint8 *nrows[MAX_IMAGE_HEIGHT];
 
     /* Figure out new height/width */
     int new_width = *width  * scale / RATIO, new_height = *height * scale / RATIO;
@@ -270,8 +243,8 @@ uint8 *rescale_rgba_data(uint8 *data, int *width, int *height, int scale)
     int sourcerow=0, ytoleft, ytofill, xtoleft, xtofill, dest_column=0, source_column=0, needcol,
         destrow=0;
     int x,y;
-    uint8 *ndata;
-    uint8 r,g,b,a;
+    guint8 *ndata;
+    guint8 r,g,b,a;
 
     if (*width > MAX_IMAGE_WIDTH || new_width > MAX_IMAGE_WIDTH
             || *height > MAX_IMAGE_HEIGHT || new_height > MAX_IMAGE_HEIGHT) {
@@ -282,7 +255,7 @@ uint8 *rescale_rgba_data(uint8 *data, int *width, int *height, int scale)
     /* clear old values these may have */
     memset(yrow, 0, sizeof(int) **height * BPP);
 
-    ndata = (uint8*)malloc(new_width * new_height * BPP);
+    ndata = (guint8*)g_malloc(new_width * new_height * BPP);
 
     for (y=0; y<new_height; y++) {
         nrows[y] = (png_bytep) (ndata + y * new_width * BPP);
@@ -435,316 +408,60 @@ uint8 *rescale_rgba_data(uint8 *data, int *width, int *height, int scale)
     return ndata;
 }
 
-
 guchar rgb[512*512*3];  /**< Make this especially big to support larger images
                          *   in the future */
 
 /**
- * Takes data that has already been converted into RGBA format (via png_to_data
- * above perhaps) and creates a GdkPixmap and GdkBitmap out of it.
- *
- * @param *window
- * @param *data
- * @param width
- * @param height
- * @param **pix
- * @param **mask
- * @param *colormap
- * @return Non-zero on error (currently, no checks for error conditions is done
+ * Create a GdkPixbuf for the given RGBA data.
  */
-int rgba_to_gdkpixmap(GdkWindow *window, uint8 *data,int width, int height,
-                      GdkPixmap **pix, GdkBitmap **mask, GdkColormap *colormap)
-{
-    GdkGC       *gc, *gc_alpha;
-    int         has_alpha=0, alpha;
-    GdkColor  scolor;
-    int x,y;
+GdkPixbuf *rgba_to_gdkpixbuf(guint8 *data, int width, int height) {
+    /* Our data doesn't have correct stride values, so we can't just create it
+     * from raw data using gdk_pixbuf_new_from_data(). */
 
-    *pix = gdk_pixmap_new(window, width, height, -1);
+    GdkPixbuf *pix;
+    pix = gdk_pixbuf_new(GDK_COLORSPACE_RGB, TRUE, 8, width, height);
 
-    gc=gdk_gc_new(*pix);
-    gdk_gc_set_function(gc, GDK_COPY);
+    int rowstride = gdk_pixbuf_get_rowstride(pix);
+    unsigned char *pixels = gdk_pixbuf_get_pixels(pix);
 
-    *mask=gdk_pixmap_new(window, width, height,1);
-    gc_alpha=gdk_gc_new(*mask);
-
-    scolor.pixel=1;
-    gdk_gc_set_foreground(gc_alpha, &scolor);
-    gdk_draw_rectangle(*mask, gc_alpha, 1, 0, 0, width, height);
-
-    scolor.pixel=0;
-    gdk_gc_set_foreground(gc_alpha, &scolor);
-
-    /* we need to draw the alpha channel.  The image may not in fact
-     * have alpha, but no way to know at this point other than to try
-     * and draw it.
-     */
-    for (y=0; y<height; y++) {
-        for (x=0; x<width; x++) {
-            alpha = data[(y * width + x) * 4 +3];
-            /* Transparent bit */
-            if (alpha==0) {
-                gdk_draw_point(*mask, gc_alpha, x, y);
-                has_alpha=1;
-            }
-        }
-    }
-
-    gdk_draw_rgb_32_image(*pix, gc,  0, 0, width, height, GDK_RGB_DITHER_NONE, data, width*4);
-    if (!has_alpha) {
-        gdk_pixmap_unref(*mask);
-        *mask = NULL;
-    }
-
-    gdk_gc_destroy(gc_alpha);
-    gdk_gc_destroy(gc);
-    return 0;
-}
-
-/**
- * Takes data that has already been converted into RGBA format (via png_to_data
- * above perhaps) and creates a GdkPixbuf of it.
- *
- * @param *data
- * @param width
- * @param height
- * @param **pix
- * @return Non-zero on error (currently, no checks for error conditions is done
- */
-int rgba_to_gdkpixbuf(uint8 *data,int width, int height,GdkPixbuf **pix)
-{
-    int         rowstride;
-    guchar  *pixels, *p;
-    int x,y;
-
-#if 0
-    /* I'm not sure why this doesn't work, since it seems
-     * the data should be in the right format, but it doesn't.
-     */
-    *pix = gdk_pixbuf_new_from_data(data, GDK_COLORSPACE_RGB,
-                                    TRUE, 8, width, height, width * 4, NULL, NULL);
-    return 0;
-
-#else
-    *pix  = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, width, height);
-
-    rowstride =  gdk_pixbuf_get_rowstride(*pix);
-    pixels = gdk_pixbuf_get_pixels(*pix);
-
-    for (y=0; y<height; y++) {
-        for (x=0; x<width; x++) {
-            p = pixels + y * rowstride + x * 4;
+    for (int y = 0; y < height; y++) {
+        for (int x = 0; x < width; x++) {
+            unsigned char *p = pixels + y * rowstride + x * 4;
             p[0] = data[4*(x + y * width)];
             p[1] = data[4*(x + y * width) + 1 ];
             p[2] = data[4*(x + y * width) + 2 ];
             p[3] = data[4*(x + y * width) + 3 ];
-
         }
     }
 
-    return 0;
-#endif
+    return pix;
 }
 
 /**
- *
- * @param *window
- * @param *data
- * @param len
- * @param **pix
- * @param **mask
- * @param *colormap
+ * Create a Cairo surface for the given RGBA data.
  */
-int png_to_gdkpixmap(GdkWindow *window, uint8 *data, int len,
-                     GdkPixmap **pix, GdkBitmap **mask, GdkColormap *colormap)
-{
-    static uint8 *pixels=NULL;
-    static int pixels_byte=0, rows_byte=0;
-    static png_bytepp   rows=NULL;
-    png_uint_32 width, height;
-    png_structp png_ptr;
-    png_infop   info_ptr;
-    int bit_depth, color_type, interlace_type, filter_type,
-        bpp, x,y,has_alpha,i,alpha;
-    GdkColor  scolor;
-    GdkGC       *gc, *gc_alpha;
+cairo_surface_t *rgba_to_cairo_surface(guint8 *data, int width, int height) {
+    cairo_surface_t *surface;
+    surface = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, width, height);
+    cairo_surface_flush(surface);
 
-    data_len=len;
-    data_cp = data;
-    data_start=0;
+    unsigned char *pixels = cairo_image_surface_get_data(surface);
+    int stride = cairo_image_surface_get_stride(surface);
 
-    png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING,
-                                     NULL, NULL, NULL);
+    for (int y = 0; y < height; y++) {
+        for (int x = 0; x < width; x++) {
+            guint32 *p = (guint32 *)(pixels + y * stride + x * 4);
 
-    if (!png_ptr) {
-        return PNGX_OUTOFMEM;
-    }
-    info_ptr = png_create_info_struct (png_ptr);
+            // Cairo format is native-endian ARGB, but our format is RGBA.
+            guint32 a = data[4 * (x + y * width) + 3];
+            guint32 r = data[4 * (x + y * width) + 0] * a / 255;
+            guint32 g = data[4 * (x + y * width) + 1] * a / 255;
+            guint32 b = data[4 * (x + y * width) + 2] * a / 255;
 
-    if (!info_ptr) {
-        png_destroy_read_struct (&png_ptr, NULL, NULL);
-        return PNGX_OUTOFMEM;
-    }
-    if (setjmp (png_jmpbuf(png_ptr))) {
-        png_destroy_read_struct (&png_ptr, &info_ptr,NULL);
-        return PNGX_DATA;
-    }
-    has_alpha=0;
-    png_set_read_fn(png_ptr, NULL, user_read_data);
-    png_read_info (png_ptr, info_ptr);
-
-    png_get_IHDR(png_ptr, info_ptr, &width, &height, &bit_depth,
-                 &color_type, &interlace_type, NULL, &filter_type);
-
-    if (color_type == PNG_COLOR_TYPE_PALETTE &&
-            bit_depth <= 8) {
-
-        /* Convert indexed images to RGB */
-        png_set_expand (png_ptr);
-
-    } else if (color_type == PNG_COLOR_TYPE_GRAY &&
-               bit_depth < 8) {
-
-        /* Convert grayscale to RGB */
-        png_set_expand (png_ptr);
-
-    } else if (png_get_valid (png_ptr,
-                              info_ptr, PNG_INFO_tRNS)) {
-
-        /* If we have transparency header, convert it to alpha
-           channel */
-        png_set_expand(png_ptr);
-
-    } else if (bit_depth < 8) {
-
-        /* If we have < 8 scale it up to 8 */
-        png_set_expand(png_ptr);
-
-
-        /* Conceivably, png_set_packing() is a better idea;
-         * God only knows how libpng works
-         */
-    }
-    /* If we are 16-bit, convert to 8-bit */
-    if (bit_depth == 16) {
-        png_set_strip_16(png_ptr);
-    }
-
-    /* If gray scale, convert to RGB */
-    if (color_type == PNG_COLOR_TYPE_GRAY ||
-            color_type == PNG_COLOR_TYPE_GRAY_ALPHA) {
-        png_set_gray_to_rgb(png_ptr);
-    }
-
-    /* If interlaced, handle that */
-    if (interlace_type != PNG_INTERLACE_NONE) {
-        png_set_interlace_handling(png_ptr);
-    }
-
-    /* Update the info the reflect our transformations */
-    png_read_update_info(png_ptr, info_ptr);
-    /* re-read due to transformations just made */
-    png_get_IHDR(png_ptr, info_ptr, &width, &height, &bit_depth,
-                 &color_type, &interlace_type, NULL, &filter_type);
-    if (color_type & PNG_COLOR_MASK_ALPHA) {
-        bpp = 4;
-    } else {
-        bpp = 3;
-    }
-
-    /* Allocate the memory we need once, and increase it if necessary.
-     * This is more efficient the allocating this block of memory every time.
-     */
-    if (pixels_byte==0) {
-        pixels_byte = width * height * bpp;
-        pixels = (uint8*)malloc(pixels_byte);
-    } else if ((width * height * bpp) > pixels_byte) {
-        pixels_byte =width * height * bpp;
-        /* Doing a free/malloc is probably more efficient -
-         * we don't care about the old data in this
-         * buffer.
-         */
-        free(pixels);
-        pixels= (uint8*)malloc(pixels_byte);
-    }
-
-    if (!pixels) {
-        png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
-        pixels_byte=0;
-        return PNGX_OUTOFMEM;
-    }
-    if (rows_byte == 0) {
-        rows = (png_bytepp)malloc(sizeof(png_byte *) * height);
-        rows_byte = height;
-    } else if (height > rows_byte) {
-        rows = (png_bytepp)realloc(rows, sizeof(png_byte *) * height);
-
-        if (rows == NULL) {
-            LOG(LOG_ERROR, "png_to_gdkpixmap",
-                    "Could not allocate memory: %s", strerror(errno));
-            exit(EXIT_FAILURE);
-        }
-
-        rows_byte = height;
-    }
-    if (!rows) {
-        png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
-        pixels_byte=0;
-        return PNGX_OUTOFMEM;
-    }
-
-    for (y=0; y<height; y++) {
-        rows[y] = pixels + y * width * bpp;
-    }
-
-    png_read_image(png_ptr, rows);
-#if 0
-    fprintf(stderr,"image is %d X %d, bpp=%d, color_type=%d\n",
-            width, height, bpp, color_type);
-#endif
-
-    *pix = gdk_pixmap_new(window, width, height, -1);
-
-
-    gc=gdk_gc_new(*pix);
-    gdk_gc_set_function(gc, GDK_COPY);
-
-    if (color_type & PNG_COLOR_MASK_ALPHA) {
-        *mask=gdk_pixmap_new(window, width, height,1);
-        gc_alpha=gdk_gc_new(*mask);
-        gdk_gc_set_function(gc_alpha, GDK_COPY);
-
-        scolor.pixel=1;
-        gdk_gc_set_foreground(gc_alpha, &scolor);
-        gdk_draw_rectangle(*mask, gc_alpha, 1, 0, 0, width, height);
-
-        scolor.pixel=0;
-        gdk_gc_set_foreground(gc_alpha, &scolor);
-        has_alpha=1;
-    } else {
-        *mask = NULL;
-        gc_alpha = NULL;    /* Prevent compile warnings */
-    }
-    i=0;
-    for (y=0; y<height; y++) {
-        for (x=0; x<width; x++) {
-            rgb[i++]=rows[y][x*bpp];    /* red */
-            rgb[i++]=rows[y][x*bpp+1];  /* green */
-            rgb[i++]=rows[y][x*bpp+2];  /* blue */
-            if (has_alpha) {
-                alpha = rows[y][x*bpp+3];
-                /* Transparent bit */
-                if (alpha==0) {
-                    gdk_draw_point(*mask, gc_alpha, x, y);
-                }
-            }
+            *p = a << (3 * 8) | r << (2 * 8) | g << (1 * 8) | b << (0 * 8);
         }
     }
-    gdk_draw_rgb_image(*pix, gc,  0, 0, 32, 32, GDK_RGB_DITHER_NONE, rgb, 32*3);
-    png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
-    if (has_alpha) {
-        gdk_gc_destroy(gc_alpha);
-    }
-    gdk_gc_destroy(gc);
-    return 0;
+
+    cairo_surface_mark_dirty(surface);
+    return surface;
 }
