@@ -12,32 +12,28 @@
  */
 
 /**
- * @file gtk-v2/src/sdl.c
+ * @file
  * Functions that implement SDL support in the GTK V2 client.
  */
 
-#include <config.h>
+#include "client.h"
 
 #ifdef HAVE_SDL
 
-#include <client-types.h>
 #include <SDL.h>
 #include <SDL_image.h>
-
-/* Pick up the gtk headers we need */
 #include <gtk/gtk.h>
+
 #ifndef WIN32
 #include <gdk/gdkx.h>
 #else
 #include <gdk/gdkwin32.h>
 #endif
-#include <gdk/gdkkeysyms.h>
 
-#include "main.h"
 #include "image.h"
-#include <client.h>
-#include "gtk2proto.h"
+#include "main.h"
 #include "mapdata.h"
+#include "gtk2proto.h"
 
 SDL_Surface* mapsurface; /**< Actual SDL surface the game view is painted on */
 static SDL_Surface* lightmap;
@@ -55,10 +51,6 @@ extern int time_map_redraw;
  * remove.
  */
 
-/* these should generally be included by the file including this file. */
-#include <SDL.h>
-#include <SDL_image.h>
-
 
 static void do_SDL_error(const char *SDL_function, const char *file, int line)
 {
@@ -318,7 +310,7 @@ void init_SDL( GtkWidget* sdl_window, int just_lightmap)
      * see if we are at the edge of the map - doing a store vs 4
      * checks is going to be much faster.
      */
-    redrawbitmap = malloc(sizeof(char) * (MAP_MAX_SIZE +2)* (MAP_MAX_SIZE+2));
+    redrawbitmap = g_malloc(sizeof(char) * (MAP_MAX_SIZE +2)* (MAP_MAX_SIZE+2));
 }
 
 
@@ -420,30 +412,30 @@ static void do_sdl_per_pixel_lighting(int x, int y, int mx, int my)
     /* I use dark0 -> dark4 in the order to keep it similar to
      * the old code.
      */
-    dark0 = the_map.cells[mx][my].darkness;
+    dark0 = mapdata_cell(mx, my)->darkness;
 
-    if (y-1 < 0 || !the_map.cells[mx][my-1].have_darkness) {
+    if (y-1 < 0 || !mapdata_cell(mx, my-1)->have_darkness) {
         dark1 = dark0;
     } else {
-        dark1 = the_map.cells[mx][my-1].darkness;
+        dark1 = mapdata_cell(mx, my-1)->darkness;
     }
 
-    if (x+1 >= use_config[CONFIG_MAPWIDTH] || !the_map.cells[mx+1][my].have_darkness) {
+    if (x+1 >= use_config[CONFIG_MAPWIDTH] || !mapdata_cell(mx+1, my)->have_darkness) {
         dark2 = dark0;
     } else {
-        dark2 = the_map.cells[mx+1][my].darkness;
+        dark2 = mapdata_cell(mx+1, my)->darkness;
     }
 
-    if (y+1 >= use_config[CONFIG_MAPHEIGHT] || !the_map.cells[mx][my+1].have_darkness) {
+    if (y+1 >= use_config[CONFIG_MAPHEIGHT] || !mapdata_cell(mx, my+1)->have_darkness) {
         dark3 = dark0;
     } else {
-        dark3 = the_map.cells[mx][my+1].darkness;
+        dark3 = mapdata_cell(mx, my+1)->darkness;
     }
 
-    if (x-1 < 0 || !the_map.cells[mx-1][my].have_darkness) {
+    if (x-1 < 0 || !mapdata_cell(mx-1, my)->have_darkness) {
         dark4 = dark0;
     } else {
-        dark4 = the_map.cells[mx-1][my].darkness;
+        dark4 = mapdata_cell(mx-1, my)->darkness;
     }
 
     /* If they are all the same, processing is easy
@@ -461,8 +453,8 @@ static void do_sdl_per_pixel_lighting(int x, int y, int mx, int my)
 
         if (dark0 == 255) {
             SDL_FillRect(mapsurface,&dst, SDL_MapRGB(mapsurface->format, 0, 0, 0));
-        } else if (the_map.cells[mx][my].darkness != 0) {
-            SDL_FillRect(lightmap,NULL, SDL_MapRGBA(lightmap->format, 0, 0, 0, the_map.cells[mx][my].darkness));
+        } else if (mapdata_cell(mx, my)->darkness != 0) {
+            SDL_FillRect(lightmap,NULL, SDL_MapRGBA(lightmap->format, 0, 0, 0, mapdata_cell(mx, my)->darkness));
             SDL_BlitSurface(lightmap, NULL, mapsurface, &dst);
         }
         return;
@@ -576,12 +568,12 @@ static void do_sdl_per_pixel_lighting(int x, int y, int mx, int my)
 
         /* Generated stored for the darkx[] array.  Do it dynamically, but
          * only allocate if the size needs to be expanded to keep performance
-         * better.  darkx could be null in the initial case, but realloc should
-         * just treat that as a malloc (so according to the man page)
+         * better.  darkx could be null in the initial case, but g_realloc should
+         * just treat that as a g_malloc (so according to the man page)
          */
         if (map_image_size > darkx_allocated) {
-            darkx = realloc(darkx, map_image_size * sizeof(int));
-            darky = realloc(darky, map_image_size * sizeof(int));
+            darkx = g_realloc(darkx, map_image_size * sizeof(int));
+            darky = g_realloc(darky, map_image_size * sizeof(int));
             darkx_allocated = map_image_size;
         }
 
@@ -609,32 +601,32 @@ static void do_sdl_per_pixel_lighting(int x, int y, int mx, int my)
         /*we need additionnal surrounding infos*/
         int dark5, dark6, dark7, dark8;
         if ( (y-1 < 0) || (x+1 >= use_config[CONFIG_MAPWIDTH])
-                || !the_map.cells[mx+1][my-1].have_darkness) {
+                || !mapdata_cell(mx+1, my-1)->darkness) {
             dark5 = (dark1+dark2)>>1;    /*(fast div 2)*/
         } else {
-            dark5 = the_map.cells[mx+1][my-1].darkness;
+            dark5 = mapdata_cell(mx+1, my-1)->darkness;
         }
 
         if ( (x+1 >= use_config[CONFIG_MAPWIDTH])
                 || (y+1 >= use_config[CONFIG_MAPHEIGHT])
-                || !the_map.cells[mx+1][my+1].have_darkness) {
+                || !mapdata_cell(mx+1, my+1)->darkness) {
             dark6 = (dark2+dark3)>>1;
         } else {
-            dark6 = the_map.cells[mx+1][my+1].darkness;
+            dark6 = mapdata_cell(mx+1, my+1)->darkness;
         }
 
         if ( (y+1 >= use_config[CONFIG_MAPHEIGHT]) || (x-1 < 0)
-                || !the_map.cells[mx-1][my+1].have_darkness) {
+                || !mapdata_cell(mx-1, my+1)->darkness) {
             dark7 = (dark3+dark4)>>1;
         } else {
-            dark7 = the_map.cells[mx-1][my+1].darkness;
+            dark7 = mapdata_cell(mx-1, my+1)->darkness;
         }
 
         if ( (x-1 < 0) || (y-1 < 0)
-                || !the_map.cells[mx-1][my-1].have_darkness) {
+                || !mapdata_cell(mx-1, my-1)->darkness) {
             dark8 = (dark4+dark1)>>1;
         } else {
-            dark8 = the_map.cells[mx-1][my-1].darkness;
+            dark8 = mapdata_cell(mx-1, my-1)->darkness;
         }
         /*upper left lightmap quarter*/
         drawquarterlightmap_sdl(dark8, dark1, dark4, dark0,                /*colors*/
@@ -703,10 +695,9 @@ static void drawsmooth_sdl (int mx,int my,int layer,SDL_Rect dst)
     int hasFace = 0;
     SDL_Rect src;
     for (i=0; i<=layer; i++) {
-        hasFace |= the_map.cells[mx][my].heads[i].face;
+        hasFace |= mapdata_cell(mx, my)->heads[i].face;
     }
-    if (!hasFace
-            || !CAN_SMOOTH(the_map.cells[mx][my], layer)) {
+    if (!hasFace || !mapdata_can_smooth(mx, my, layer)) {
         return;
     }
 
@@ -716,15 +707,15 @@ static void drawsmooth_sdl (int mx,int my,int layer,SDL_Rect dst)
     for (i=0; i<8; i++) {
         emx=mx+dx[i];
         emy=my+dy[i];
-        if ( (emx<0) || (emy<0) || (the_map.x<=emx) || (the_map.y<=emy)) {
+        if (!mapdata_contains(emx, emy)) {
             slevels[i]=0;
             sfaces[i]=0; /*black picture*/
-        } else if (the_map.cells[emx][emy].smooth[layer]<=the_map.cells[mx][my].smooth[layer]) {
+        } else if (mapdata_cell(emx, emy)->smooth[layer]<=mapdata_cell(mx, my)->smooth[layer]) {
             slevels[i]=0;
             sfaces[i]=0; /*black picture*/
         } else {
-            slevels[i]=the_map.cells[emx][emy].smooth[layer];
-            sfaces[i]=pixmaps[the_map.cells[emx][emy].heads[layer].face]->smooth_face;
+            slevels[i]=mapdata_cell(emx, emy)->smooth[layer];
+            sfaces[i]=pixmaps[mapdata_cell(emx, emy)->heads[layer].face]->smooth_face;
         }
     }
     /* ok, now we have a list of smoothlevel higher than current square.
@@ -787,7 +778,7 @@ static void drawsmooth_sdl (int mx,int my,int layer,SDL_Rect dst)
         if (weight>0) {
             src.x=map_image_size*weight;
             src.y=0;
-            if (the_map.cells[mx][my].cleared) {
+            if (mapdata_cell(mx, my)->cleared) {
                 if (SDL_BlitSurface(pixmaps[smoothface]->fog_image,
                                     &src, mapsurface, &dst)) {
                     do_SDL_error( "BlitSurface", __FILE__, __LINE__);
@@ -802,7 +793,7 @@ static void drawsmooth_sdl (int mx,int my,int layer,SDL_Rect dst)
         if (weightC>0) {
             src.x=map_image_size*weightC;
             src.y=map_image_size;
-            if (the_map.cells[mx][my].cleared) {
+            if (mapdata_cell(mx, my)->cleared) {
                 if (SDL_BlitSurface(pixmaps[smoothface]->fog_image,
                                     &src, mapsurface, &dst)) {
                     do_SDL_error( "BlitSurface", __FILE__, __LINE__);
@@ -846,7 +837,7 @@ static void update_redrawbitmap(void)
              * memory area allows the memset above, which is an optimized routine
              * to clear memory.
              */
-            if (the_map.cells[mx][my].need_update) {
+            if (mapdata_cell(mx, my)->need_update) {
                 redrawbitmap[x + 1 + (y+1) * use_config[CONFIG_MAPWIDTH]] = 1;
                 /* If this space has changed, and using non tile lighting,
                  * we need to update the neighbor spaces.  Ideally, we'd
@@ -870,7 +861,7 @@ static void update_redrawbitmap(void)
                     redrawbitmap[x +  (y+2) * use_config[CONFIG_MAPWIDTH]] = 1;
                     redrawbitmap[x + 2 + (y+2) * use_config[CONFIG_MAPWIDTH]] = 1;
                 }
-            } else if (the_map.cells[mx][my].need_resmooth) {
+            } else if (mapdata_cell(mx, my)->need_resmooth) {
                 redrawbitmap[x + 1 + (y+1) * use_config[CONFIG_MAPWIDTH]] = 1;
             }
         }
@@ -899,7 +890,7 @@ static void display_mapcell(int ax, int ay, int mx, int my)
     /* now draw the different layers.  Only draw if using fog of war or the
      * space isn't clear.
      */
-    if (use_config[CONFIG_FOGWAR] || !the_map.cells[mx][my].cleared) {
+    if (use_config[CONFIG_FOGWAR] || !mapdata_cell(mx, my)->cleared) {
         for (layer=0; layer<MAXLAYERS; layer++) {
             int sx, sy;
 
@@ -915,7 +906,7 @@ static void display_mapcell(int ax, int ay, int mx, int my)
                 src.h = map_image_size;
                 dst.x = ax*map_image_size;
                 dst.y = ay*map_image_size;
-                if (the_map.cells[mx][my].cleared) {
+                if (mapdata_cell(mx, my)->cleared) {
                     if (SDL_BlitSurface(pixmaps[face]->fog_image, &src, mapsurface, &dst)) {
                         do_SDL_error( "BlitSurface", __FILE__, __LINE__);
                     }
@@ -972,7 +963,7 @@ static void display_mapcell(int ax, int ay, int mx, int my)
                 src.h = map_image_size - offy;
                 dst.x = ax*map_image_size + offx;
                 dst.y = ay*map_image_size + offy;
-                if (the_map.cells[mx][my].cleared) {
+                if (mapdata_cell(mx, my)->cleared) {
                     if (SDL_BlitSurface(pixmaps[face]->fog_image, &src, mapsurface, &dst)) {
                         do_SDL_error( "BlitSurface", __FILE__, __LINE__);
                     }
@@ -995,10 +986,10 @@ static void display_mapcell(int ax, int ay, int mx, int my)
          * directly onto the map surface - I would think this should be
          * faster
          */
-        if (the_map.cells[mx][my].darkness == 255) {
+        if (mapdata_cell(mx, my)->darkness == 255) {
             SDL_FillRect(mapsurface,&dst, SDL_MapRGB(mapsurface->format, 0, 0, 0));
-        } else if (the_map.cells[mx][my].darkness != 0) {
-            SDL_SetAlpha(lightmap, SDL_SRCALPHA|SDL_RLEACCEL, the_map.cells[mx][my].darkness);
+        } else if (mapdata_cell(mx, my)->darkness != 0) {
+            SDL_SetAlpha(lightmap, SDL_SRCALPHA|SDL_RLEACCEL, mapdata_cell(mx, my)->darkness);
             SDL_BlitSurface(lightmap, NULL, mapsurface, &dst);
         }
     } else if (use_config[CONFIG_LIGHTING] == CFG_LT_PIXEL || use_config[CONFIG_LIGHTING] == CFG_LT_PIXEL_BEST) {
@@ -1030,16 +1021,8 @@ static void display_mapcell(int ax, int ay, int mx, int my)
  *
  * @param redraw
  */
-void sdl_gen_map(int redraw)
-{
-    int x, y, num_spaces=0, num_drawn=0;
-    struct timeval tv1, tv2, tv3;
-    long elapsed1, elapsed2;
-
-    if (time_map_redraw) {
-        gettimeofday(&tv1, NULL);
-    }
-
+void sdl_gen_map(int redraw) {
+    int x, y, num_spaces = 0, num_drawn = 0;
     update_redrawbitmap();
 
     for( x= 0; x<use_config[CONFIG_MAPWIDTH]; x++) {
@@ -1052,30 +1035,14 @@ void sdl_gen_map(int redraw)
             if (redraw || redrawbitmap[x + 1 + (y+1) * use_config[CONFIG_MAPWIDTH]]) {
                 num_drawn++;
                 display_mapcell(x, y, pl_pos.x+x, pl_pos.y+y);
-                the_map.cells[pl_pos.x+x][pl_pos.y+y].need_update = 0;
-                the_map.cells[pl_pos.x+x][pl_pos.y+y].need_resmooth = 0;
+                mapdata_cell(pl_pos.x+x, pl_pos.y+y)->need_update = 0;
+                mapdata_cell(pl_pos.x+x, pl_pos.y+y)->need_resmooth = 0;
             }
         }
     }
 
-    if (time_map_redraw) {
-        gettimeofday(&tv2, NULL);
-    }
-
     SDL_Flip(mapsurface);
-
-    if (time_map_redraw) {
-        gettimeofday(&tv3, NULL);
-        elapsed1 = (tv2.tv_sec - tv1.tv_sec)*1000000 + (tv2.tv_usec - tv1.tv_usec);
-        elapsed2 = (tv3.tv_sec - tv2.tv_sec)*1000000 + (tv3.tv_usec - tv2.tv_usec);
-
-        /* I care about performance for 'long' updates, so put the check in to make
-         * these a little more noticable */
-        if ((elapsed1 + elapsed2)>10000)
-            LOG(LOG_INFO,"gtk-v2::sdl_gen_map","gen took %7ld, flip took %7ld, total = %7ld",
-                elapsed1, elapsed2, elapsed1 + elapsed2);
-    }
-} /* sdl_gen_map function */
+}
 
 /**
  *
